@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: commands.c,v 1.34 2007/02/20 10:17:13 smorlat Exp $
+ *  $Id: commands.c,v 1.36 2007/08/01 14:47:53 strk Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2004  Simon MORLAT <simon.morlat@linphone.org>
@@ -118,17 +118,17 @@ LPC_COMMAND commands[] = {
 	},
 	{ "nat", lpc_cmd_nat, "Set nat address",
 		"'nat'        : show nat settings.\n"
-		"'nat <addr>' : set nat address (and enable its use).\n"
+		"'nat <addr>' : set nat address.\n"
 	},
 	{ "stun", lpc_cmd_stun, "Set stun server address",
 		"'stun'        : show stun settings.\n"
-		"'stun <addr>' : set stun address (and enable its use).\n"
+		"'stun <addr>' : set stun address.\n"
 	},
 	{ "firewall", lpc_cmd_firewall, "Set ",
 		"'firewall'        : show current firewall policy.\n"
-		"'firewall none' : use direct connection.\n"
-		"'firewall nat' : use nat address given with the 'nat' command.\n"
-		"'firewall stun' : use stun server given with the 'server' command.\n"
+		"'firewall none'   : use direct connection.\n"
+		"'firewall nat'    : use nat address given with the 'nat' command.\n"
+		"'firewall stun'   : use stun server given with the 'server' command.\n"
 	},
         { "call-logs", lpc_cmd_call_logs, "Calls history",
                 NULL },
@@ -314,7 +314,11 @@ lpc_cmd_call(LinphoneCore *lc, char *args)
 static int
 lpc_cmd_refer(LinphoneCore *lc, char *args)
 {
-	linphone_core_refer(lc, args);
+	if (args)
+		linphone_core_refer(lc, args);
+	else{
+		printf("refer needs an argument\n");
+	}
 	return 1;
 }
 
@@ -356,12 +360,12 @@ lpc_cmd_nat(LinphoneCore *lc, char *args)
 	if ( args && *args )
 	{
 		linphone_core_set_nat_address(lc, args);
-		linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_NAT_ADDRESS);
+		/* linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_NAT_ADDRESS); */
 	}
 
 	nat = linphone_core_get_nat_address(lc);
 	use = linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_NAT_ADDRESS;
-	printf("Nat address: %s%s\n", nat, use?"":" (unused)");
+	printf("Nat address: %s%s\n", nat ? nat : "unspecified" , use ? "" : " (disabled - use 'firewall nat' to enable)");
 
 	return 1;
 }
@@ -370,19 +374,19 @@ static int
 lpc_cmd_stun(LinphoneCore *lc, char *args)
 {
 	bool_t use;
-	const char *nat;
+	const char *stun;
 
 	if ( args ) args=lpc_strip_blanks(args);
 
 	if ( args && *args )
 	{
 		linphone_core_set_stun_server(lc, args);
-		linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_STUN);
+		/* linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_STUN); */
 	}
 
-	nat = linphone_core_get_stun_server(lc);
+	stun = linphone_core_get_stun_server(lc);
 	use = linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_STUN;
-	printf("Stun server: %s%s\n", nat, use?"":" (unused)");
+	printf("Stun server: %s%s\n", stun ? stun : "unspecified" , use? "" : " (disabled - use 'firewall stun' to enable)");
 
 	return 1;
 }
@@ -390,26 +394,48 @@ lpc_cmd_stun(LinphoneCore *lc, char *args)
 static int
 lpc_cmd_firewall(LinphoneCore *lc, char *args)
 {
+	const char* setting=NULL;
+
 	if ( args ) args=lpc_strip_blanks(args);
 
 	if ( args && *args )
 	{
 		if (strcmp(args,"none")==0)
+		{
 			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_NO_FIREWALL);
+		}
 		else if (strcmp(args,"stun")==0)
+		{
+			setting = linphone_core_get_stun_server(lc);
+			if ( ! setting )
+			{
+				printf("No stun server address is defined, use 'stun <address>' first");
+				return 1;
+			}
 			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_STUN);
+		}
 		else if (strcmp(args,"nat")==0)
+		{
+			setting = linphone_core_get_nat_address(lc);
+			if ( ! setting )
+			{
+				printf("No nat address is defined, use 'nat <address>' first");
+				return 1;
+			}
 			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_NAT_ADDRESS);
+		}
 	}
-	switch(linphone_core_get_firewall_policy(lc)){
+
+	switch(linphone_core_get_firewall_policy(lc))
+	{
 		case LINPHONE_POLICY_NO_FIREWALL:
 			printf("No firewall\n");
 			break;
 		case LINPHONE_POLICY_USE_STUN:
-			printf("Using stun server to discover firewall address\n");
+			printf("Using stun server %s to discover firewall address\n", setting ? setting : linphone_core_get_stun_server(lc));
 			break;
 		case LINPHONE_POLICY_USE_NAT_ADDRESS:
-			printf("Using supplied nat address.\n");
+			printf("Using supplied nat address %s.\n", setting ? setting : linphone_core_get_nat_address(lc));
 			break;
 	}
 	return 1;
@@ -512,7 +538,7 @@ lpc_cmd_friend(LinphoneCore *lc, char *args)
 			addr_p = addr + strlen("sip:");
 		}
 		addr_orig = strsep(&args, " ");
-		if (1 <= strlen(addr_orig)) {
+		if (1 >= strlen(addr_orig)) {
 			fprintf(stderr, "A single-digit address is not valid\n");
 			return 0;
 		}
@@ -1104,6 +1130,13 @@ lpc_find_command(const char *name)
 /****************************************************************************
  *
  * $Log: commands.c,v $
+ * Revision 1.36  2007/08/01 14:47:53  strk
+ *         * console/commands.c: Clean up commands 'nat', 'stun'
+ *           and 'firewall' to be more intuitive.
+ *
+ * Revision 1.35  2007/06/27 09:01:25  smorlat
+ * logging improvements.
+ *
  * Revision 1.34  2007/02/20 10:17:13  smorlat
  * linphonec friends patch2
  *
