@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: linphonec.c,v 1.53 2007/02/13 21:31:01 smorlat Exp $
+ *  $Id: linphonec.c,v 1.57 2007/11/14 13:40:27 smorlat Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2002  Florian Winterstein <flox@gmx.net>
@@ -93,6 +93,8 @@ static void linphonec_bye_received(LinphoneCore *lc, const char *from);
 static void linphonec_text_received(LinphoneCore *lc, LinphoneChatRoom *cr,
 		const char *from, const char *msg);
 static void linphonec_display_status (LinphoneCore * lc, const char *something);
+static void linphonec_general_state (LinphoneCore * lc, LinphoneGeneralState *gstate);
+static void print_prompt(LinphoneCore *opm);
 
 /***************************************************************************
  *
@@ -107,7 +109,9 @@ static char last_in_history[256];
 //auto answer (-a) option
 static bool_t auto_answer=FALSE;
 static bool_t answer_call=FALSE;
-static bool_t video_enabled=FALSE;
+static bool_t vcap_enabled=FALSE;
+static bool_t display_enabled=FALSE;
+static bool_t show_general_state=FALSE;
 LPC_AUTH_STACK auth_stack;
 static int trace_level = 0;
 static char *logfile_name = NULL;
@@ -130,9 +134,9 @@ LinphoneCoreVTable linphonec_vtable = {
 #endif
 	display_warning:linphonec_display_warning,
 	display_url:linphonec_display_url,
-	display_question:stub,
+	display_question:(DisplayQuestionCb)stub,
 	text_received:linphonec_text_received,
-        general_state:NULL
+        general_state:linphonec_general_state
 };
 
 /***************************************************************************
@@ -147,7 +151,8 @@ LinphoneCoreVTable linphonec_vtable = {
 static void
 linphonec_display_something (LinphoneCore * lc, const char *something)
 {
-	fprintf (stdout, "%s\n", something);
+	fprintf (stdout, "%s\n%s", something,prompt);
+	fflush(stdout);
 }
 
 /*
@@ -156,7 +161,8 @@ linphonec_display_something (LinphoneCore * lc, const char *something)
 static void
 linphonec_display_status (LinphoneCore * lc, const char *something)
 {
-	fprintf (stdout, "%s\n", something);
+	fprintf (stdout, "%s\n%s", something,prompt);
+	fflush(stdout);
 }
 
 /*
@@ -165,7 +171,8 @@ linphonec_display_status (LinphoneCore * lc, const char *something)
 static void
 linphonec_display_warning (LinphoneCore * lc, const char *something)
 {
-	fprintf (stdout, "Warning: %s\n", something);
+	fprintf (stdout, "Warning: %s\n%s", something,prompt);
+	fflush(stdout);
 }
 
 /*
@@ -260,7 +267,60 @@ linphonec_text_received(LinphoneCore *lc, LinphoneChatRoom *cr,
 }
 
 
-
+static void 
+linphonec_general_state (LinphoneCore * lc, LinphoneGeneralState *gstate)
+{
+        if (show_general_state) {
+          switch(gstate->new_state) {
+           case GSTATE_POWER_OFF:
+             printf("GSTATE_POWER_OFF");
+             break;
+           case GSTATE_POWER_STARTUP:
+             printf("GSTATE_POWER_STARTUP");
+             break;
+           case GSTATE_POWER_ON:
+             printf("GSTATE_POWER_ON");
+             break;
+           case GSTATE_POWER_SHUTDOWN:
+             printf("GSTATE_POWER_SHUTDOWN");
+             break;
+           case GSTATE_REG_NONE:
+             printf("GSTATE_REG_NONE");
+             break;
+           case GSTATE_REG_OK:
+             printf("GSTATE_REG_OK");
+             break;
+           case GSTATE_REG_FAILED:
+             printf("GSTATE_REG_FAILED");
+             break;
+           case GSTATE_CALL_IDLE:
+             printf("GSTATE_CALL_IDLE");
+             break;
+           case GSTATE_CALL_OUT_INVITE:
+             printf("GSTATE_CALL_OUT_INVITE");
+             break;
+           case GSTATE_CALL_OUT_CONNECTED:
+             printf("GSTATE_CALL_OUT_CONNECTED");
+             break;
+           case GSTATE_CALL_IN_INVITE:
+             printf("GSTATE_CALL_IN_INVITE");
+             break;
+           case GSTATE_CALL_IN_CONNECTED:
+             printf("GSTATE_CALL_IN_CONNECTED");
+             break;
+           case GSTATE_CALL_END:
+             printf("GSTATE_CALL_END");
+             break;
+           case GSTATE_CALL_ERROR:
+             printf("GSTATE_CALL_ERROR");
+             break;
+           default:
+              printf("GSTATE_UNKNOWN_%d",gstate->new_state);   
+          }
+          if (gstate->message) printf(" %s", gstate->message);
+          printf("\n");
+        }  
+}
 
 
 /***************************************************************************/
@@ -356,8 +416,8 @@ linphonec_init(int argc, char **argv)
 	 */
 	linphone_core_init (&linphonec, &linphonec_vtable, configfile_name,
 			    NULL);
-	linphone_core_enable_video(&linphonec,video_enabled);
-	if (!video_enabled) printf("Warning: video is disabled in linphonec. Run with -V option to enable it.\n");
+	linphone_core_enable_video(&linphonec,vcap_enabled,display_enabled);
+	if (!(vcap_enabled || display_enabled)) printf("Warning: video is disabled in linphonec.\n");
 	/*
 	 * Initialize readline
 	 */
@@ -495,7 +555,10 @@ usage: linphonec [-c file] [-s sipaddr] [-a] [-V] [-d level ] [-l logfile]\n\
   -l  logfile          specify the log file for your SIP phone\n\
   -s  sipaddress       specify the sip call to do at startup\n\
   -a                   enable auto answering for incoming calls\n\
-  -V                   enable video (disabled by default)\n\
+  -V                   enable video features globally (disabled by default)\n\
+  -C                   enable video capture only (disabled by default)\n\
+  -D                   enable video display only (disabled by default)\n\
+  -S                   show general state messages (disabled by default)\n\
   -v or --version      display version and exits.\n");
 
   	exit(exit_status);
@@ -579,7 +642,7 @@ linphonec_initialize_readline()
 	rl_attempted_completion_function = linephonec_readline_completion;
 
 	/* printf("Readline initialized.\n"); */
-
+        setlinebuf(stdout); 
 	return 0;
 }
 
@@ -601,6 +664,15 @@ linphonec_finish_readline()
 	return 0;
 }
 
+static void print_prompt(LinphoneCore *opm){
+#ifdef IDENTITY_AS_PROMPT
+	snprintf(prompt, PROMPT_MAX_LEN, "%s> ",
+		linphone_core_get_primary_contact(opm));
+#else
+	snprintf(prompt, PROMPT_MAX_LEN, "linphonec> ");
+#endif
+}
+
 static int
 linphonec_main_loop (LinphoneCore * opm, char * sipAddr)
 {
@@ -608,13 +680,8 @@ linphonec_main_loop (LinphoneCore * opm, char * sipAddr)
 	bool_t run=TRUE;
 	char *input;
 
+	print_prompt(opm);
 
-#ifdef IDENTITY_AS_PROMPT
-	snprintf(prompt, PROMPT_MAX_LEN, "%s> ",
-		linphone_core_get_primary_contact(opm));
-#else
-	snprintf(prompt, PROMPT_MAX_LEN, "linphonec> ");
-#endif
 
 	/* auto call handling */
 	if (sipAddr != NULL )
@@ -717,9 +784,18 @@ linphonec_parse_cmdline(int argc, char **argv)
                 {
                         auto_answer = TRUE;
                 }
+		else if (strncmp ("-C", argv[arg_num], 2) == 0)
+                {
+                        vcap_enabled = TRUE;
+                }
+		else if (strncmp ("-D", argv[arg_num], 2) == 0)
+                {
+                        display_enabled = TRUE;
+                }
 		else if (strncmp ("-V", argv[arg_num], 2) == 0)
                 {
-                        video_enabled = TRUE;
+                        display_enabled = TRUE;
+			vcap_enabled = TRUE;
                 }
 		else if ((strncmp ("-v", argv[arg_num], 2) == 0)
 			 ||
@@ -730,6 +806,10 @@ linphonec_parse_cmdline(int argc, char **argv)
 			printf ("version: " LINPHONE_VERSION "\n");
 			exit (EXIT_SUCCESS);
 		}
+		else if (strncmp ("-S", argv[arg_num], 2) == 0)
+		{
+			show_general_state = TRUE;
+		}
 		else if (old_arg_num == arg_num)
 		{
 			fprintf (stderr, "ERROR: bad arguments\n");
@@ -929,6 +1009,20 @@ lpc_strip_blanks(char *input)
 /****************************************************************************
  *
  * $Log: linphonec.c,v $
+ * Revision 1.57  2007/11/14 13:40:27  smorlat
+ * fix --disable-video build.
+ *
+ * Revision 1.56  2007/09/26 14:07:27  fixkowalski
+ * - ANSI/C++ compilation issues with non-GCC compilers
+ * - Faster epm-based packaging
+ * - Ability to build & run on FC6's eXosip/osip
+ *
+ * Revision 1.55  2007/09/24 16:01:58  smorlat
+ * fix bugs.
+ *
+ * Revision 1.54  2007/08/22 14:06:11  smorlat
+ * authentication bugs fixed.
+ *
  * Revision 1.53  2007/02/13 21:31:01  smorlat
  * added patch for general state.
  * new doxygen for oRTP
