@@ -24,34 +24,40 @@
  
  #include "linphonecore.h"
  #include "private.h"
- #include <eXosip.h>
+ #include <eXosip2/eXosip.h>
  
- LinphoneChatRoom * linphone_core_create_chat_room(LinphoneCore *lc, const char *to)
- {
-	 char *real_url=NULL;
-	 osip_from_t *parsed_url=NULL;
-	 if (linphone_core_interpret_url(lc,to,&real_url,&parsed_url)){
-	 	LinphoneChatRoom *cr=ms_new0(LinphoneChatRoom,1);
-	 	cr->lc=lc;
-	 	cr->peer=real_url;
+ LinphoneChatRoom * linphone_core_create_chat_room(LinphoneCore *lc, const char *to){
+	char *real_url=NULL;
+	osip_from_t *parsed_url=NULL;
+	char *route;
+	if (linphone_core_interpret_url(lc,to,&real_url,&parsed_url,&route)){
+		LinphoneChatRoom *cr=ms_new0(LinphoneChatRoom,1);
+		cr->lc=lc;
+		cr->peer=real_url;
 		cr->peer_url=parsed_url;
-	 	lc->chatrooms=ms_list_append(lc->chatrooms,(void *)cr);
-	 	return cr;
-	 }
-	 return NULL;
+		cr->route=route;
+		lc->chatrooms=ms_list_append(lc->chatrooms,(void *)cr);
+		return cr;
+	}
+	return NULL;
  }
  
  
  void linphone_chat_room_destroy(LinphoneChatRoom *cr){
-	 LinphoneCore *lc=cr->lc;
-	 lc->chatrooms=ms_list_remove(lc->chatrooms,(void *) cr);
-	 osip_from_free(cr->peer_url);
-	 ms_free(cr->peer);
+	LinphoneCore *lc=cr->lc;
+	lc->chatrooms=ms_list_remove(lc->chatrooms,(void *) cr);
+	osip_from_free(cr->peer_url);
+	ms_free(cr->peer);
+	ms_free(cr->route);
  }
  
 void linphone_chat_room_send_message(LinphoneChatRoom *cr, const char *msg){
 	const char *identity=linphone_core_get_identity(cr->lc);
-	eXosip_message(cr->peer,(char*)identity, (char*)linphone_core_get_route(cr->lc),(char*)msg);
+	osip_message_t *sip=NULL;
+	eXosip_message_build_request(&sip,"MESSAGE",cr->peer,identity,cr->route);
+	osip_message_set_content_type(sip,"text/plain");
+	osip_message_set_body(sip,msg,strlen(msg));
+	eXosip_message_send_request(sip);
 }
 
 bool_t linphone_chat_room_matches(LinphoneChatRoom *cr, osip_from_t *from){
@@ -63,17 +69,20 @@ void linphone_chat_room_text_received(LinphoneChatRoom *cr, LinphoneCore *lc, co
 	if (lc->vtable.text_received!=NULL) lc->vtable.text_received(lc, cr, from, msg);
 }
 
-void linphone_core_text_received(LinphoneCore *lc, const char *from, const char *msg){
+void linphone_core_text_received(LinphoneCore *lc, eXosip_event_t *ev){
 	MSList *elem;
+	const char *msg;
 	LinphoneChatRoom *cr=NULL;
 	char *cleanfrom;
-	osip_from_t *from_url;
-	osip_from_init(&from_url);
-	if (osip_from_parse(from_url,from)<0){
-		ms_warning("linphone_core_text_received: could not parse %s.",from);
-		osip_from_free(from_url);
+	osip_from_t *from_url=ev->request->from;
+	osip_body_t *body=NULL;
+
+	osip_message_get_body(ev->request,0,&body);
+	if (body==NULL){
+		ms_error("Could not get text message from SIP body");
 		return;
 	}
+	msg=body->body;
 	from_2char_without_params(from_url,&cleanfrom);
 	for(elem=lc->chatrooms;elem!=NULL;elem=ms_list_next(elem)){
 		cr=(LinphoneChatRoom*)elem->data;
@@ -87,7 +96,6 @@ void linphone_core_text_received(LinphoneCore *lc, const char *from, const char
 		cr=linphone_core_create_chat_room(lc,cleanfrom);
 	}
 	linphone_chat_room_text_received(cr,lc,cleanfrom,msg);
-	osip_from_free(from_url);
 	osip_free(cleanfrom);
 }
 
