@@ -24,7 +24,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <eXosip2/eXosip.h>
 #include <osipparser2/osip_message.h>
 
-int linphone_answer_sdp(LinphoneCore *lc, eXosip_event_t *ev, sdp_message_t *sdp);
+static int linphone_answer_sdp(LinphoneCore *lc, eXosip_event_t *ev, sdp_message_t *sdp);
+
+static void linphone_call_proceeding(LinphoneCore *lc, eXosip_event_t *ev){
+	if (lc->call==NULL){
+		ms_warning("Bug in call_proceeding()");
+		return;
+	}
+	lc->call->cid=ev->cid;
+	lc->call->did=ev->did;
+	lc->call->tid=ev->tid;
+}
 
 static void linphone_connect_incoming(LinphoneCore *lc){
 	lc->vtable.show(lc);
@@ -53,6 +63,7 @@ int linphone_call_accepted(LinphoneCore *lc, eXosip_event_t *ev)
 		ms_warning("No call to accept.");
 		return 0;
 	}
+	linphone_call_proceeding(lc,ev);
 	call->auth_pending=FALSE;
 	if (call->state==LCStateAVRunning){
 		return 0; /*already accepted*/
@@ -216,7 +227,7 @@ int linphone_call_failure(LinphoneCore *lc, eXosip_event_t *ev)
 
 extern sdp_handler_t linphone_sdphandler;
 
-int linphone_answer_sdp(LinphoneCore *lc, eXosip_event_t *ev, sdp_message_t *sdp){
+static int linphone_answer_sdp(LinphoneCore *lc, eXosip_event_t *ev, sdp_message_t *sdp){
 	int status=200;
 	sdp_context_t *ctx=NULL;
 	
@@ -681,23 +692,12 @@ int linphone_read_video_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 	return 0;
 }
 
-void linphone_call_proceeding(LinphoneCore *lc, eXosip_event_t *ev){
-	if (lc->call==NULL){
-		ms_warning("Bug in call_proceeding()");
-		return;
-	}
-	lc->call->cid=ev->cid;
-	lc->call->did=ev->did;
-	lc->call->tid=ev->tid;
-}
-
 void linphone_call_ringing(LinphoneCore *lc, eXosip_event_t *ev){
 	sdp_message_t *sdp=eXosip_get_sdp_info(ev->response);
 	LinphoneCall *call=lc->call;
 	
 	linphone_call_proceeding(lc,ev);
 	
-
 	if (sdp==NULL){
 		if (lc->ringstream!=NULL) return;	/*already ringing !*/
 		if (lc->sound_conf.play_sndcard!=NULL){
