@@ -214,6 +214,8 @@ bool_t linphone_core_check_payload_type_usability(const LinphoneCore *lc, Payloa
 			if (min_video_bw!=0) {/* infinite (-1) or strictly positive*/
 				if (strcmp(pt->mime_type,"H263-1998")==0){
 					payload_type_set_recv_fmtp(pt,"CIF=1;QCIF=1");
+				}else if (strcmp(pt->mime_type,"H264")==0){
+					payload_type_set_recv_fmtp(pt,"packetization-mode=1");
 				}
 				/*let the video use all the bandwidth minus the maximum bandwidth used by audio */
 				if (min_video_bw>0)
