@@ -19,7 +19,7 @@
 #include "sdphandler.h"
 #include <osipparser2/osip_port.h>
 #include <osipparser2/sdp_message.h>
-#include <eXosip.h>
+#include <eXosip2/eXosip.h>
 #include "linphonecore.h"
 
 #define keywordcmp(key,str)  strncmp(key,str,strlen(key))
@@ -57,10 +57,6 @@ char *sdp_message_a_attr_value_get_with_pt(sdp_message_t *sdp,int pos,int pt,con
 					tmp=attr->a_att_value+scanned;
 					if (strlen(tmp)>0)
 						return tmp;
-					else {
-						eXosip_trace(OSIP_WARNING,("sdp has a strange a= line."));
-						continue;
-					}
 				}
 			}else eXosip_trace(OSIP_WARNING,("sdp has a strange a= line (%s) nb=%i",attr->a_att_value,nb));
 		}
@@ -68,7 +64,20 @@ char *sdp_message_a_attr_value_get_with_pt(sdp_message_t *sdp,int pos,int pt,con
 	return NULL;
 }
 
-
+static int _sdp_message_get_a_ptime(sdp_message_t *sdp, int mline){
+	int i,ret;
+	sdp_attribute_t *attr;
+	for (i=0;(attr=sdp_message_attribute_get(sdp,mline,i))!=NULL;i++){
+		if (keywordcmp("ptime",attr->a_att_field)==0){
+			int nb = sscanf(attr->a_att_value,"%i",&ret);
+			/* the return value may depend on how %n is interpreted by the libc: see manpage*/
+			if (nb == 1){
+				return ret;
+			}else eXosip_trace(OSIP_WARNING,("sdp has a strange a=ptime line (%s) ",attr->a_att_value));
+		}
+	}
+	return 0;
+}
 
 int
 sdp_payload_init (sdp_payload_t * payload)
@@ -232,9 +241,9 @@ static void refuse_mline(sdp_message_t *answer,char *mtype,char *proto, int mlin
 }
 
 char *
-sdp_context_get_answer ( sdp_context_t *ctx,const char *remote_offer)
+sdp_context_get_answer ( sdp_context_t *ctx,sdp_message_t *remote)
 {
-	sdp_message_t *answer=NULL,*remote=NULL;
+	sdp_message_t *answer=NULL;
 	char *mtype=NULL, *tmp=NULL, *bw=NULL;
 	char *proto=NULL, *port=NULL, *pt=NULL;
 	int i, j, ncodec, m_lines_accepted = 0;
@@ -242,21 +251,13 @@ sdp_context_get_answer ( sdp_context_t *ctx,const char *remote_offer)
 	sdp_payload_t payload;
 	sdp_handler_t *sdph=ctx->handler;
 
-	
-	sdp_message_init(&remote);
-	err=sdp_message_parse(remote,remote_offer);
-	if (err<0) {
-		eXosip_trace(OSIP_WARNING,("Could not parse remote offer."));
-		return NULL;
-	}
-	ctx->remote=remote;
-
 	tmp = sdp_message_c_addr_get (remote, 0, 0);
 	if (tmp == NULL)
 	  tmp = sdp_message_c_addr_get (remote, -1, 0);
 	if (ctx->localip==NULL) {
 		/* NULL means guess, otherwise we use the address given as localip */
-		eXosip_get_localip_for(tmp,&ctx->localip);
+		ctx->localip=osip_malloc(128);
+		eXosip_guess_localip(strchr(tmp,':') ?  AF_INET6 : AF_INET,ctx->localip,128);
 	}
 	else eXosip_trace(OSIP_INFO1,("Using firewall address in sdp."));
 
@@ -278,6 +279,7 @@ sdp_context_get_answer ( sdp_context_t *ctx,const char *remote_offer)
 		/* get application specific bandwidth, if any */
 		bw=sdp_message_b_bandwidth_get(remote, i, 0);
 		if (bw!=NULL) payload.b_as_bandwidth=atoi(bw);
+		payload.a_ptime=_sdp_message_get_a_ptime(remote,i);
 		if (keywordcmp ("audio", mtype) == 0)
 		{
 			if (sdph->accept_audio_codecs != NULL)
@@ -481,10 +483,14 @@ sdp_context_get_answer ( sdp_context_t *ctx,const char *remote_offer)
 			}
 		}
 	}
+	if (ctx->answer!=NULL)
+		sdp_message_free(ctx->answer);
 	ctx->answer = answer;
 	if (m_lines_accepted > 0){
 		ctx->negoc_status = 200;
 		sdp_message_to_str(answer,&tmp);
+		if (ctx->answerstr!=NULL)
+			osip_free(ctx->answerstr);
 		ctx->answerstr=tmp;
 		return tmp;
 	}else{
@@ -494,22 +500,14 @@ sdp_context_get_answer ( sdp_context_t *ctx,const char *remote_offer)
 }
 
 void
-sdp_context_read_answer (sdp_context_t *ctx, const char *remote_answer)
+sdp_context_read_answer (sdp_context_t *ctx, sdp_message_t *remote)
 {
-	sdp_message_t *remote;
 	char *mtype;
 	char *proto, *port, *pt, *bw;
 	int i, j,err;
 	sdp_payload_t payload;
 	sdp_handler_t *sdph=ctx->handler;
 
-	sdp_message_init(&remote);
-	err=sdp_message_parse(remote,remote_answer);
-	if (err<0) {
-		eXosip_trace(OSIP_WARNING,("Could not parse remote offer."));
-		return ;
-	}
-	ctx->remote=remote;
 	/* for each m= line */
 	for (i = 0; !sdp_message_endof_media (remote, i); i++)
 	{
@@ -526,6 +524,7 @@ sdp_context_read_answer (sdp_context_t *ctx, const char *remote_answer)
 			payload.c_addr = sdp_message_c_addr_get (remote, -1, 0);
 		bw=sdp_message_b_bandwidth_get(remote, i, 0);
 		if (bw!=NULL) payload.b_as_bandwidth=atoi(bw);
+		payload.a_ptime=_sdp_message_get_a_ptime(remote,i);
 		if (keywordcmp ("audio", mtype) == 0)
 		{
 			if (sdph->get_audio_codecs != NULL)
@@ -555,7 +554,7 @@ sdp_context_read_answer (sdp_context_t *ctx, const char *remote_answer)
 		}
 		else if (keywordcmp ("video", mtype) == 0)
 		{
-			if (sdph->accept_video_codecs != NULL)
+			if (sdph->get_video_codecs != NULL)
 			{
 				/* for each payload type */
 				for (j = 0;
@@ -586,7 +585,6 @@ void sdp_context_free(sdp_context_t *ctx){
 	osip_free(ctx->localip);
 	osip_free(ctx->username);
 	if (ctx->offer!=NULL) sdp_message_free(ctx->offer);
-	if (ctx->remote!=NULL) sdp_message_free(ctx->remote);
 	if (ctx->answer!=NULL) sdp_message_free(ctx->answer);
 	if (ctx->offerstr!=NULL) osip_free(ctx->offerstr);
 	if (ctx->answerstr!=NULL) osip_free(ctx->answerstr);
