@@ -72,7 +72,11 @@ typedef enum MSFilterId{
 	MS_SNOW_DEC_ID,
 	MS_SNOW_ENC_ID,
 	MS_CA_READ_ID,
-	MS_CA_WRITE_ID
+	MS_CA_WRITE_ID,
+#ifdef __DIRECTSOUND_ENABLED__
+	MS_WINSNDDS_READ_ID,
+	MS_WINSNDDS_WRITE_ID
+#endif
 } MSFilterId;
 
 
