@@ -336,6 +336,16 @@ int ms_snd_card_get_level(MSSndCard *obj, MSSndCardMixerElem e);
  */
 void ms_snd_card_set_capture(MSSndCard *obj, MSSndCardCapture c);
 
+/**
+ * Create a alsa card with user supplied pcm name and mixer name.
+ * @param pcmdev The pcm device name following alsa conventions (ex: plughw:0)
+ * @param mixdev The mixer device name following alsa conventions.
+ *
+ * Returns: a MSSndCard object, NULL if alsa support is not available.
+ */
+MSSndCard * ms_alsa_card_new_custom(const char *pcmdev, const char *mixdev);
+
+
 /** @} */
 
 #ifdef __cplusplus
