@@ -68,11 +68,13 @@ typedef enum{
 	MS_YUY2   /* -> same as MS_YUYV */
 }MSPixFmt;
 
-typedef struct _YuvBuf{
+typedef struct _MSPicture{
 	int w,h;
 	uint8_t *planes[4]; /*we usually use 3 planes, 4th is for compatibility */
 	int strides[4];	/*with ffmpeg's swscale.h */
-}YuvBuf;
+}MSPicture;
+
+typedef struct _MSPicture YuvBuf; /*for backward compatibility*/
 
 #ifdef __cplusplus
 extern "C"{
@@ -81,10 +83,11 @@ extern "C"{
 int ms_pix_fmt_to_ffmpeg(MSPixFmt fmt);
 MSPixFmt ffmpeg_pix_fmt_to_ms(int fmt);
 void ms_ffmpeg_check_init(void);
-int yuv_buf_init_from_mblk(YuvBuf *buf, mblk_t *m);
-void yuv_buf_init_from_mblk_with_size(YuvBuf *buf, mblk_t *m, int w, int h);
-mblk_t * yuv_buf_alloc(YuvBuf *buf, int w, int h);
-
+int yuv_buf_init_from_mblk(MSPicture *buf, mblk_t *m);
+void yuv_buf_init_from_mblk_with_size(MSPicture *buf, mblk_t *m, int w, int h);
+mblk_t * yuv_buf_alloc(MSPicture *buf, int w, int h);
+void yuv_buf_copy(uint8_t *src_planes[], const int src_strides[], 
+		uint8_t *dst_planes[], const int dst_strides[3], MSVideoSize roi);
 #ifdef __cplusplus
 }
 #endif
