@@ -25,6 +25,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer2/msfilter.h"
 #include "mediastreamer2/mssndcard.h"
 
+/*in case of troubles with a particular driver, try incrementing ALSA_PERIOD_SIZE
+to 512, 1024, 2048, 4096...
+then try incrementing the number of periods*/
+#define ALSA_PERIODS 8
+#define ALSA_PERIOD_SIZE 256
+
 /*uncomment the following line if you have problems with an alsa driver
 having sound quality trouble:*/
 /*#define EPIPE_BUGFIX 1*/
@@ -51,8 +57,8 @@ static int alsa_set_params(snd_pcm_t *pcm_handle, int rw, int bits, int stereo,
 	uint exact_uvalue;
 	unsigned long exact_ulvalue;
 	int channels;
-	int periods=8;
-	int periodsize=256;
+	int periods=ALSA_PERIODS;
+	int periodsize=ALSA_PERIOD_SIZE;
 	int err;
 	int format;
 	
@@ -134,7 +140,9 @@ static int alsa_set_params(snd_pcm_t *pcm_handle, int rw, int bits, int stereo,
 		snd_pcm_sw_params_current(pcm_handle, swparams);
 		if ((err=snd_pcm_sw_params_set_start_threshold(pcm_handle, swparams,periodsize*2 ))<0){
 			ms_warning("alsa_set_params: Error setting start threshold:%s",snd_strerror(err));
-			return -1;
+		}
+		if ((err=snd_pcm_sw_params_set_stop_threshold(pcm_handle, swparams,periodsize*periods ))<0){
+			ms_warning("alsa_set_params: Error setting start threshold:%s",snd_strerror(err));
 		}
 		if ((err=snd_pcm_sw_params(pcm_handle, swparams))<0){
 			ms_warning("alsa_set_params: Error setting SW params:%s",snd_strerror(err));
@@ -214,6 +222,33 @@ static snd_pcm_t * alsa_open_w(const char *pcmdev,int bits,int stereo,int rate)
 	return pcm_handle;
 }
 
+static bool_t alsa_can_read(snd_pcm_t *dev, int frames)
+{
+	snd_pcm_sframes_t avail;
+	int err;
+
+	avail = snd_pcm_avail_update(dev);
+	ms_debug("*** %s %d %d", __FUNCTION__, (long)avail, frames);
+	if (avail < 0) {
+		ms_error("snd_pcm_avail_update: %s\n", snd_strerror(avail));	// most probably -EPIPE
+		/* overrun occured, snd_pcm_state() would return SND_PCM_STATE_XRUN
+		 FIXME: handle other error conditions*/
+		ms_error("*** alsa_can_read fixup, trying to recover");
+		snd_pcm_drain(dev); /* Ignore possible error, at least -EAGAIN.*/
+		err = snd_pcm_recover(dev, avail, 0);
+		if (err){ 
+			ms_error("snd_pcm_recover() failed with err %d: %s", err, snd_strerror(err));
+			return FALSE;
+		}
+		err = snd_pcm_start(dev);
+		if (err){ 
+			ms_error("snd_pcm_start() failed with err %d: %s\n", err, snd_strerror(err)); 
+			return FALSE; 
+		}
+		ms_message("Recovery done\n");
+	}
+	return avail >= frames;
+}
 
 static int alsa_read(snd_pcm_t *handle,unsigned char *buf,int nsamples)
 {
@@ -298,7 +333,7 @@ static int get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction ac
 	elem=snd_mixer_first_elem(mixer);
 	while (elem!=NULL){
 		elemname=snd_mixer_selem_get_name(elem);
-		//g_message("Found alsa mixer element %s.",elemname);
+		//ms_message("Found alsa mixer element %s.",elemname);
 		if (strcmp(elemname,name)==0){
 			switch (action){
 				case CAPTURE:
@@ -308,7 +343,7 @@ static int get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction ac
 					newvol-=sndMixerPMin;
 					value=(100*newvol)/(sndMixerPMax-sndMixerPMin);
 					if (err<0) ms_warning("Could not get capture volume for %s:%s",name,snd_strerror(err));
-					//else ms_message("Succesfully get capture level for %s.",elemname);
+					//else ms_message("Successfully get capture level for %s.",elemname);
 					break;
 				}
 				break;
@@ -319,7 +354,7 @@ static int get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction ac
 					newvol-=sndMixerPMin;
 					value=(100*newvol)/(sndMixerPMax-sndMixerPMin);
 					if (err<0) ms_warning("Could not get playback volume for %s:%s",name,snd_strerror(err));
-					//else g_message("Succesfully get playback level for %s.",elemname);
+					//else ms_message("Successfully get playback level for %s.",elemname);
 					break;
 				}
 				break;
@@ -349,7 +384,7 @@ static void set_mixer_element(snd_mixer_t *mixer,const char *name, int level,Mix
 	
 	while (elem!=NULL){
 		elemname=snd_mixer_selem_get_name(elem);
-		//g_message("Found alsa mixer element %s.",elemname);
+		//ms_message("Found alsa mixer element %s.",elemname);
 		if (strcmp(elemname,name)==0){
 			switch(action){
 				case CAPTURE:
@@ -357,7 +392,7 @@ static void set_mixer_element(snd_mixer_t *mixer,const char *name, int level,Mix
 					snd_mixer_selem_get_capture_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
 					newvol=(((sndMixerPMax-sndMixerPMin)*level)/100)+sndMixerPMin;
 					snd_mixer_selem_set_capture_volume_all(elem,newvol);
-					//g_message("Succesfully set capture level for %s.",elemname);
+					//ms_message("Successfully set capture level for %s.",elemname);
 					return;
 				}
 				break;
@@ -366,20 +401,20 @@ static void set_mixer_element(snd_mixer_t *mixer,const char *name, int level,Mix
 					snd_mixer_selem_get_playback_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
 					newvol=(((sndMixerPMax-sndMixerPMin)*level)/100)+sndMixerPMin;
 					snd_mixer_selem_set_playback_volume_all(elem,newvol);
-					//g_message("Succesfully set playback level for %s.",elemname);
+					//ms_message("Successfully set playback level for %s.",elemname);
 					return;
 				}
 				break;
 				case CAPTURE_SWITCH:
 				if (snd_mixer_selem_has_capture_switch(elem)){
 					snd_mixer_selem_set_capture_switch_all(elem,level);
-					//g_message("Succesfully set capture switch for %s.",elemname);
+					//ms_message("Successfully set capture switch for %s.",elemname);
 				}
 				break;
 				case PLAYBACK_SWITCH:
 				if (snd_mixer_selem_has_playback_switch(elem)){
 					snd_mixer_selem_set_playback_switch_all(elem,level);
-					//g_message("Succesfully set capture switch for %s.",elemname);
+					//ms_message("Successfully set capture switch for %s.",elemname);
 				}
 				break;
 
@@ -510,9 +545,10 @@ static MSSndCard *alsa_card_duplicate(MSSndCard *obj){
 	AlsaData* dcard=(AlsaData*)card->data;
 	AlsaData* dobj=(AlsaData*)obj->data;
 	card->name=ms_strdup(obj->name);
+	card->id=ms_strdup(obj->id);
 	dcard->pcmdev=ms_strdup(dobj->pcmdev);
 	dcard->mixdev=ms_strdup(dobj->mixdev);
-	return obj;
+	return card;
 }
 
 MSSndCard * ms_alsa_card_new_custom(const char *pcmdev, const char *mixdev){
@@ -591,10 +627,6 @@ void alsa_read_uninit(MSFilter *obj){
 	ms_free(ad);
 }
 
-static bool_t alsa_can_read(snd_pcm_t *dev, int frames){
-	return snd_pcm_avail_update(dev)>=frames;
-}
-
 void alsa_read_process(MSFilter *obj){
 	AlsaReadData *ad=(AlsaReadData*)obj->data;
 #ifdef AMD_HACK
