@@ -137,7 +137,7 @@ void audio_stream_change_decoder(AudioStream *stream, int payload){
 			ms_filter_destroy(stream->decoder);
 			stream->decoder=dec;
 			if (pt->recv_fmtp!=NULL)
-				ms_filter_call_method(stream->decoder,MS_FILTER_SET_FMTP,(void*)pt->recv_fmtp);
+				ms_filter_call_method(stream->decoder,MS_FILTER_ADD_FMTP,(void*)pt->recv_fmtp);
 			ms_filter_link (stream->rtprecv, 0, stream->decoder, 0);
 			ms_filter_link (stream->decoder,0 , stream->dtmfgen, 0);
 			ms_filter_preprocess(stream->decoder,stream->ticker);
@@ -224,8 +224,8 @@ int audio_stream_start_full(AudioStream *stream, RtpProfile *profile, const char
 	}
 	ms_filter_call_method(stream->decoder,MS_FILTER_SET_SAMPLE_RATE,&pt->clock_rate);
 	
-	if (pt->send_fmtp!=NULL) ms_filter_call_method(stream->encoder,MS_FILTER_SET_FMTP, (void*)pt->send_fmtp);
-	if (pt->recv_fmtp!=NULL) ms_filter_call_method(stream->decoder,MS_FILTER_SET_FMTP,(void*)pt->recv_fmtp);
+	if (pt->send_fmtp!=NULL) ms_filter_call_method(stream->encoder,MS_FILTER_ADD_FMTP, (void*)pt->send_fmtp);
+	if (pt->recv_fmtp!=NULL) ms_filter_call_method(stream->decoder,MS_FILTER_ADD_FMTP,(void*)pt->recv_fmtp);
 	
 	/* and then connect all */
 	/* tip: draw yourself the picture if you don't understand */
@@ -318,7 +318,7 @@ void audio_stream_record(AudioStream *st, const char *name){
 
 
 AudioStream *audio_stream_new(int locport, bool_t ipv6){
-	AudioStream *stream=ms_new0(AudioStream,1);
+	AudioStream *stream=(AudioStream *)ms_new0(AudioStream,1);
 	stream->session=create_duplex_rtpsession(locport,ipv6);
 	return stream;
 }
@@ -359,7 +359,7 @@ RingStream * ring_start_with_cb(const char *file,int interval,MSSndCard *sndcard
 {
 	RingStream *stream;
 	int tmp;
-	stream=ms_new0(RingStream,1);
+	stream=(RingStream *)ms_new0(RingStream,1);
 	stream->source=ms_filter_new(MS_FILE_PLAYER_ID);
 	if (ms_filter_call_method(stream->source,MS_FILE_PLAYER_OPEN,(void*)file)<0){
 		ms_filter_destroy(stream->source);
