@@ -17,12 +17,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#if !defined(_WIN32_WCE) //Allready defined for wince
 #define UNICODE
+#endif
 
 #include <streams.h>
 #include <initguid.h>
 
+#if !defined(_WIN32_WCE)
 #include "qedit.h"
+#endif
 #include "dxfilter.h"
 
 #pragma warning(disable: 4800)
@@ -130,7 +134,11 @@ CUnknown * WINAPI CDXFilter::CreateInstance(LPUNKNOWN punk, HRESULT *phr)
 
 CDXFilter::CDXFilter( IUnknown * pOuter, HRESULT * phr, BOOL ModifiesData )
                 : CTransInPlaceFilter( TEXT("DXFilter"), (IUnknown*) pOuter, 
-                                       CLSID_DXFilter, phr, (BOOL)ModifiesData )
+                                       CLSID_DXFilter, phr
+#if !defined(_WIN32_WCE)
+									   ,(BOOL)ModifiesData
+#endif
+									   )
                 , m_callback( NULL )
 {
     // this is used to override the input pin with our own   
@@ -192,13 +200,125 @@ HRESULT CDXFilter::CheckInputType( const CMediaType * pmt )
     }
 
     // subtypes must match, if set. if not set, accept anything
+	VIDEOINFO *pvi = (VIDEOINFO *)pmt->Format();
 
     g = *m_mtAccept.Subtype( );
     if( g == GUID_NULL )
     {
         return NOERROR;
     }
-    if( g != *pmt->Subtype( ) )
+#if 0
+	if( MEDIASUBTYPE_RGB24 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_YVU9 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Y411 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Y41P == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_YUY2 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_YVYU == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_UYVY == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Y211 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_YV12 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_CLJR == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_IF09 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_CPLA == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MJPG == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_TVMJ == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_WAKE == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_CFCC == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_IJPG == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Plum == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB1 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB1 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB1 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB4 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB8 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB565 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB555 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB24 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_RGB32 == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Overlay == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1Packet == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1Payload == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1AudioPayload == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIATYPE_MPEG1SystemStream == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1System == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1VideoCD == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_MPEG1Video == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Avi == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_Asf == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_QTMovie == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_QTRpza == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_QTSmc == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_QTRle == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_QTJpeg == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_PCM == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_WAVE == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_AU == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_AIFF == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_DssVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVBI == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+    if( MEDIASUBTYPE_VPVideo == *pmt->Subtype( ) )
+        return VFW_E_INVALID_MEDIA_TYPE;
+#endif
+
+	if( g != *pmt->Subtype( ) )
     {
         return VFW_E_INVALID_MEDIA_TYPE;
     }
@@ -219,15 +339,17 @@ HRESULT CDXFilter::CheckInputType( const CMediaType * pmt )
     // but you may want to make it more strict
 
 	//compare sizes
-	VIDEOINFO *pvi = (VIDEOINFO *)pmt->Format();
+	//VIDEOINFO *pvi = (VIDEOINFO *)pmt->Format();
 	VIDEOINFO *pvi2 = (VIDEOINFO *)m_mtAccept.Format();
 	if (pvi2==NULL)
 		return NOERROR;
 
 	if (pvi==NULL)
 		return VFW_E_INVALID_MEDIA_TYPE;
+#if !defined(_WIN32_WCE)
 	if (pvi->bmiHeader.biCompression!=pvi2->bmiHeader.biCompression)
 		return VFW_E_INVALID_MEDIA_TYPE;
+#endif
 	if (pvi->bmiHeader.biBitCount!=pvi2->bmiHeader.biBitCount)
 		return VFW_E_INVALID_MEDIA_TYPE;
 	if (pvi->bmiHeader.biWidth!=pvi2->bmiHeader.biWidth)
@@ -236,8 +358,6 @@ HRESULT CDXFilter::CheckInputType( const CMediaType * pmt )
 		return VFW_E_INVALID_MEDIA_TYPE;
 	if (pvi->bmiHeader.biSizeImage!=pvi2->bmiHeader.biSizeImage)
 		return VFW_E_INVALID_MEDIA_TYPE;
-//	if (pvi->bmiHeader.biPlanes!=pvi2->bmiHeader.biPlanes)
-//		return VFW_E_INVALID_MEDIA_TYPE;
 
     return NOERROR;
 }
@@ -264,6 +384,7 @@ HRESULT CDXFilter::Receive( IMediaSample * pms )
             return NOERROR;
     }
 
+#if !defined(_WIN32_WCE)
     if (UsingDifferentAllocators()) 
     {
         // We have to copy the data.
@@ -275,18 +396,21 @@ HRESULT CDXFilter::Receive( IMediaSample * pms )
             return E_UNEXPECTED;
         }
     }
+#endif
 
     // have the derived class transform the data
     hr = Transform(pms);
 
     if (FAILED(hr)) 
     {
-        DbgLog((LOG_TRACE, 1, TEXT("Error from TransInPlace")));
+        //DbgLog((LOG_TRACE, 1, TEXT("Error from TransInPlace")));
+#if !defined(_WIN32_WCE)
         if (UsingDifferentAllocators()) 
         {
             pms->Release();
         }
-        return hr;
+#endif
+		return hr;
     }
 
     if (hr == NOERROR) 
@@ -296,11 +420,12 @@ HRESULT CDXFilter::Receive( IMediaSample * pms )
     
     // release the output buffer. If the connected pin still needs it,
     // it will have addrefed it itself.
+#if !defined(_WIN32_WCE)
     if (UsingDifferentAllocators()) 
     {
         pms->Release();
     }
-
+#endif
     return hr;
 }
 
@@ -350,8 +475,12 @@ STDMETHODIMP CDXFilter::SetAcceptedMediaType( const CMediaType * pmt )
     }
 
     HRESULT hr;
+#if !defined(_WIN32_WCE)
     hr = CopyMediaType( &m_mtAccept, pmt );
-
+#else
+	hr=S_OK;
+    CopyMediaType( &m_mtAccept, pmt );
+#endif
     return hr;
 }
 
@@ -476,12 +605,14 @@ STDMETHODIMP CDXFilterInPin::NotifyAllocator( IMemAllocator *pAllocator, BOOL bR
         }
         else
         {
-            // if the upstream guy wants to be read only and we don't, then that's bad
+#if !defined(_WIN32_WCE)
+			// if the upstream guy wants to be read only and we don't, then that's bad
             // if the upstream guy doesn't request read only, but we do, that's okay
             if( bReadOnly && !DXFilter( )->IsReadOnly( ) )
             {
                 return E_FAIL;
             }
+#endif
         }
     }
 
