@@ -18,6 +18,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #if !defined(WIN32) && !defined(_WIN32_WCE)
+#ifdef __APPLE__
+#include <sys/types.h>
+#endif
 #include <sys/socket.h>
 #include <netdb.h>
 #endif
