@@ -218,8 +218,11 @@ MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(cons
 
 
 
-
+#ifdef __APPLE__
+#define PLUGINS_EXT ".dylib"
+#else
 #define PLUGINS_EXT ".so"
+#endif
 
 typedef void (*init_func_t)(void);
 
@@ -325,11 +328,28 @@ int ms_load_plugins(const char *dir){
 			}else {
 				char *initroutine_name=ms_malloc0(strlen(de->d_name)+10);
 				char *p;
-				void *initroutine;
+				void *initroutine=NULL;
 				strcpy(initroutine_name,de->d_name);
 				p=strstr(initroutine_name,PLUGINS_EXT);
-				strcpy(p,"_init");
-				initroutine=dlsym(handle,initroutine_name);
+				if (p!=NULL)
+				  {
+				    strcpy(p,"_init");
+				    initroutine=dlsym(handle,initroutine_name);
+				  }
+
+#ifdef __APPLE__
+				if (initroutine==NULL){
+				  /* on macosx: library name are libxxxx.1.2.3.dylib */
+				  /* -> MUST remove the .1.2.3 */
+				  p=strstr(initroutine_name,".");
+				  if (p!=NULL)
+				    {
+				      strcpy(p,"_init");
+				      initroutine=dlsym(handle,initroutine_name);
+				    }
+				}
+#endif
+
 				if (initroutine!=NULL){
 					init_func_t func=(init_func_t)initroutine;
 					func();
@@ -368,6 +388,10 @@ extern MSSndCardDesc arts_card_desc;
 extern MSSndCardDesc winsnd_card_desc;
 #endif
 
+#ifdef __DIRECTSOUND_ENABLED__
+extern MSSndCardDesc winsndds_card_desc;
+#endif
+
 #ifdef __MACSND_ENABLED__
 extern MSSndCardDesc ca_card_desc;
 #endif
@@ -389,6 +413,9 @@ static MSSndCardDesc * ms_snd_card_descs[]={
 #ifdef WIN32
 	&winsnd_card_desc,
 #endif
+#ifdef __DIRECTSOUND_ENABLED__
+	&winsndds_card_desc,
+#endif
 #ifdef __PORTAUDIO_ENABLED__
 	&pasnd_card_desc,
 #endif
@@ -471,3 +498,13 @@ void ms_sleep(int seconds){
 	}while(err==-1 && errno==EINTR);
 #endif
 }
+
+static int max_payload_size=1440;
+
+int ms_get_payload_max_size(){
+	return max_payload_size;
+}
+
+void ms_set_payload_max_size(int size){
+	max_payload_size=size;
+}
