@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "mediastreamer2/msfilter.h"
 
+#if defined(_WIN32_WCE)
+#define DISABLE_SPEEX
+#endif
+
 #ifndef DISABLE_SPEEX
 #include <speex/speex_preprocess.h>
 #endif
