@@ -37,12 +37,15 @@ struct _PlayerData{
 	int loop_after;
 	int pause_time;
 	bool_t swap;
+
+	int stat;
+	int big_buffer; /* ouput less & bigger buffer. (default => no change) */
 };
 
 typedef struct _PlayerData PlayerData;
 
 static void player_init(MSFilter *f){
-	PlayerData *d=ms_new(PlayerData,1);
+	PlayerData *d=(PlayerData *)ms_new(PlayerData,1);
 	d->fd=INVALID_HANDLE_VALUE;
 	d->state=CLOSED;
 	d->swap=FALSE;
@@ -51,6 +54,8 @@ static void player_init(MSFilter *f){
 	d->hsize=0;
 	d->loop_after=-1;
 	d->pause_time=0;
+	d->stat=-1;
+	d->big_buffer=1;
 	f->data=d;	
 }
 
@@ -82,8 +87,13 @@ static int player_open(MSFilter *f, void *arg){
 	PlayerData *d=(PlayerData*)f->data;
 	HANDLE fd;
 	const char *file=(const char*)arg;
-    fd = CreateFile(file, GENERIC_READ, FILE_SHARE_READ, NULL,
+#if defined(_WIN32_WCE)
+    fd = CreateFile((LPCWSTR)file, GENERIC_READ, FILE_SHARE_READ, NULL,
         OPEN_EXISTING, 0, NULL);
+#else
+	fd = CreateFile(file, GENERIC_READ, FILE_SHARE_READ, NULL,
+        OPEN_EXISTING, 0, NULL);
+#endif
 	if (fd==INVALID_HANDLE_VALUE){
 		ms_warning("Failed to open %s",file);
 		return -1;
@@ -99,6 +109,7 @@ static int player_close(MSFilter *f, void *arg){
 	if (d->fd!=INVALID_HANDLE_VALUE)	CloseHandle(d->fd);
 	d->fd=NULL;
 	d->state=CLOSED;
+	d->stat=-1;
 	return 0;
 }
 
@@ -113,6 +124,7 @@ static int player_stop(MSFilter *f, void *arg){
 	PlayerData *d=(PlayerData*)f->data;
 	if (d->state==STARTED){
 		d->state=STOPPED;
+		d->stat=-1;
         SetFilePointer(d->fd, d->hsize, NULL, FILE_BEGIN);
 	}
 	return 0;
@@ -126,7 +138,21 @@ static void player_uninit(MSFilter *f){
 
 static void player_process(MSFilter *f){
 	PlayerData *d=(PlayerData*)f->data;
-	int bytes=2*(f->ticker->interval*d->rate*d->nchannels)/1000;
+	int bytes =d->big_buffer * 2*(f->ticker->interval*d->rate*d->nchannels)/1000;;
+
+	if (d->big_buffer>1)
+	{
+		/* when starting reading a file: prepare more data
+		so that sound card buffer will never remain empty.
+		*/
+		d->stat++;
+		if (d->stat>3)
+		{
+			if (d->stat%(d->big_buffer)!=0)
+				return;
+		}
+	}
+
 	if (d->state==STARTED){
 		unsigned long err;
 		mblk_t *om=allocb(bytes,0);
@@ -140,11 +166,15 @@ static void player_process(MSFilter *f){
             res = ReadFile(d->fd, om->b_wptr, bytes, &err, NULL) ;            
 		}
 		if (err>=0){
-			if (err!=0){
-				om->b_wptr+=bytes;
+			if (err==bytes){
+				om->b_wptr+=err;
 				ms_queue_put(f->outputs[0],om);
-			}else freemsg(om);
-			if (err<bytes){
+			}
+			else if (err>0){
+				BOOL res;
+
+				om->b_wptr+=err;
+
 				ms_filter_notify_no_arg(f,MS_FILE_PLAYER_EOF);
 				SetFilePointer(d->fd, d->hsize, NULL, FILE_BEGIN);
 
@@ -156,8 +186,52 @@ static void player_process(MSFilter *f){
 				}
 
 				if (d->loop_after>0)
+				{
+					d->stat=-1;
 					d->pause_time=d->loop_after;
+				}
+				else
+				{
+					bytes=bytes-err;
+					err=0;
+					res = ReadFile(d->fd, om->b_wptr, bytes, &err, NULL);
+					if (err>0){
+						om->b_wptr+=err;
+					}
+				}
+
+				ms_queue_put(f->outputs[0],om);
 			}
+			else if (err==0){
+				BOOL res;
+				ms_filter_notify_no_arg(f,MS_FILE_PLAYER_EOF);
+				SetFilePointer(d->fd, d->hsize, NULL, FILE_BEGIN);
+
+				if (d->loop_after==-2)
+				{
+					player_close(f,NULL);
+					return;
+				}
+
+				if (d->loop_after>0)
+				{
+					d->stat=-1;
+					d->pause_time=d->loop_after;
+				}
+				else
+				{
+					bytes=bytes-err;
+					err=0;
+					res = ReadFile(d->fd, om->b_wptr, bytes, &err, NULL);
+					if (err>0){
+						om->b_wptr+=err;
+						ms_queue_put(f->outputs[0],om);
+						return;
+					}
+				}
+				freemsg(om);
+
+			}else freemsg(om);
 		}else{
 #if !defined(_WIN32_WCE)
 			ms_warning("Fail to read %i bytes: %s",bytes,strerror(errno));
@@ -180,6 +254,12 @@ static int player_loop(MSFilter *f, void *arg){
 	return 0;
 }
 
+static int player_set_big_buffer(MSFilter *f, void *arg){
+	PlayerData *d=(PlayerData*)f->data;
+	d->big_buffer=*((int*)arg);
+	return 0;
+}
+
 static int player_eof(MSFilter *f, void *arg){
 	PlayerData *d=(PlayerData*)f->data;
 	if (d->fd==NULL && d->state==CLOSED)
@@ -204,6 +284,7 @@ static MSFilterMethod player_methods[]={
 	{	MS_FILTER_GET_NCHANNELS, player_get_nch	},
 	{	MS_FILE_PLAYER_LOOP,	player_loop	},
 	{	MS_FILE_PLAYER_DONE,	player_eof	},
+	{	MS_FILE_PLAYER_BIG_BUFFER,	player_set_big_buffer	},
 	{	0,			NULL		}
 };
 
