@@ -42,7 +42,7 @@ typedef struct RecState{
 } RecState;
 
 static void rec_init(MSFilter *f){
-	RecState *s=ms_new(RecState,1);
+	RecState *s=(RecState *)ms_new(RecState,1);
 	s->fd=INVALID_HANDLE_VALUE;
 	s->rate=8000;
 	s->size=0;
@@ -101,7 +101,11 @@ static void write_wav_header(int rate,int size, char *filename){
 	header.data_chunk.len=le_uint32(size);
 
 	/* TODO: replace with "lseek" equivalent for windows */
+#if defined(_WIN32_WCE)
+	fd=CreateFile((LPCWSTR)filename, GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
+#else
 	fd=CreateFile(filename, GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
+#endif
 	if (fd==INVALID_HANDLE_VALUE){
 #if !defined(_WIN32_WCE)
 		ms_warning("Cannot open %s: %s",filename,strerror(errno));
@@ -122,7 +126,11 @@ static int rec_open(MSFilter *f, void *arg){
 	const char *filename=(const char*)arg;
 	ms_mutex_lock(&f->lock);
 	snprintf(s->filename, sizeof(s->filename), "%s", filename);
+#if defined(_WIN32_WCE)
+	s->fd=CreateFile((LPCWSTR)filename, GENERIC_WRITE, 0, NULL, CREATE_ALWAYS, 0, NULL);
+#else
 	s->fd=CreateFile(filename, GENERIC_WRITE, 0, NULL, CREATE_ALWAYS, 0, NULL);
+#endif
 	if (s->fd==INVALID_HANDLE_VALUE){
 #if !defined(_WIN32_WCE)
 		ms_warning("Cannot open %s: %s",filename,strerror(errno));
