@@ -26,7 +26,8 @@ void ms_filter_register(MSFilterDesc *desc){
 	if (desc->id==MS_FILTER_NOT_SET_ID){
 		ms_fatal("MSFilterId for %s not set !",desc->name);
 	}
-	desc_list=ms_list_append(desc_list,desc);
+	/*lastly registered encoder/decoders may replace older ones*/
+	desc_list=ms_list_prepend(desc_list,desc);
 }
 
 void ms_filter_unregister_all(){
