@@ -32,6 +32,13 @@ MSQueue * ms_queue_new(struct _MSFilter *f1, int pin1, struct _MSFilter *f2, int
 	return q;
 }
 
+void ms_queue_init(MSQueue *q){
+	q->prev.filter=0;
+	q->prev.pin=0;
+	q->next.filter=0;
+	q->next.pin=0;
+	qinit(&q->q);
+}
 
 void ms_queue_destroy(MSQueue *q){
 	flushq(&q->q,0);
