@@ -102,14 +102,18 @@ static int sender_set_session(MSFilter * f, void *arg)
 static int sender_mute_mic(MSFilter * f, void *arg)
 {
 	SenderData *d = (SenderData *) f->data;
+	ms_filter_lock(f);
 	d->mute_mic=TRUE;
+	ms_filter_unlock(f);
 	return 0;
 }
 
 static int sender_unmute_mic(MSFilter * f, void *arg)
 {
 	SenderData *d = (SenderData *) f->data;
+	ms_filter_lock(f);
 	d->mute_mic=FALSE;
+	ms_filter_unlock(f);
 	return 0;
 }
 
@@ -276,13 +280,13 @@ static void receiver_postprocess(MSFilter * f)
 	ReceiverData *d = (ReceiverData *) f->data;
 	if (d->session!=NULL && d->ortp_event!=NULL)
 	  rtp_session_unregister_event_queue(d->session, d->ortp_event);
-	if (d->ortp_event!=NULL)
-	  ortp_ev_queue_destroy(d->ortp_event);
-	d->ortp_event=NULL;
 }
 
 static void receiver_uninit(MSFilter * f)
 {
+	ReceiverData *d = (ReceiverData *) f->data;
+	if (d->ortp_event!=NULL)
+	  ortp_ev_queue_destroy(d->ortp_event);
 	ms_free(f->data);
 }
 
@@ -300,7 +304,6 @@ static int receiver_set_session(MSFilter * f, void *arg)
 	}
 	d->session = s;
 
-	rtp_session_register_event_queue(s, d->ortp_event);
 	return 0;
 }
 
@@ -328,6 +331,8 @@ static void receiver_preprocess(MSFilter * f){
 				rtp_session_flush_sockets(d->session);
 		}
 	}
+	if (d->session!=NULL && d->ortp_event!=NULL)
+		rtp_session_register_event_queue(d->session, d->ortp_event);
 }
 
 static void receiver_process(MSFilter * f)
