@@ -18,6 +18,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "mediastreamer2/mssndcard.h"
+#ifdef HAVE_CONFIG_H
+#include "mediastreamer-config.h"
+#endif
 
 static MSSndCardManager *scm=NULL;
 
@@ -44,9 +47,10 @@ MSSndCard * ms_snd_card_manager_get_card(MSSndCardManager *m, const char *id){
 	MSList *elem;
 	for (elem=m->cards;elem!=NULL;elem=elem->next){
 		MSSndCard *card=(MSSndCard*)elem->data;
+		if (id==NULL) return card;
 		if (strcmp(ms_snd_card_get_string_id(card),id)==0)	return card;
 	}
-	ms_warning("no card with id %s",id);
+	if (id!=NULL) ms_warning("no card with id %s",id);
 	return NULL;
 }
 
@@ -152,3 +156,12 @@ void ms_snd_card_destroy(MSSndCard *obj){
 	if (obj->id!=NULL)	ms_free(obj->id);
 	ms_free(obj);
 }
+
+#ifdef __linux
+#ifndef __ALSA_ENABLED__
+MSSndCard * ms_alsa_card_new_custom(const char *pcmdev, const char *mixdev){
+	ms_warning("Alsa support not available in this build of mediastreamer2");
+	return NULL;
+}
+#endif
+#endif
