@@ -40,7 +40,7 @@ typedef struct EncState{
 } EncState;
 
 static void enc_init(MSFilter *f){
-	EncState *s=ms_new(EncState,1);
+	EncState *s=(EncState *)ms_new(EncState,1);
 	s->rate=8000;
 	s->bitrate=-1;
 	s->maxbitrate=-1;
@@ -340,22 +340,32 @@ static int enc_add_fmtp(MSFilter *f, void *arg){
 static int enc_add_attr(MSFilter *f, void *arg){
 	const char *fmtp=(const char *)arg;
 	EncState *s=(EncState*)f->data;
-	if (strstr(fmtp,"ptime:20")!=NULL){
+	if (strstr(fmtp,"ptime:10")!=NULL){
+		s->ptime=20;
+	}else if (strstr(fmtp,"ptime:20")!=NULL){
 		s->ptime=20;
 	}else if (strstr(fmtp,"ptime:30")!=NULL){
 		s->ptime=40; /* not allowed */
 	}else if (strstr(fmtp,"ptime:40")!=NULL){
 		s->ptime=40;
+	}else if (strstr(fmtp,"ptime:50")!=NULL){
+		s->ptime=60;
 	}else if (strstr(fmtp,"ptime:60")!=NULL){
 		s->ptime=60;
+	}else if (strstr(fmtp,"ptime:70")!=NULL){
+		s->ptime=80;
 	}else if (strstr(fmtp,"ptime:80")!=NULL){
 		s->ptime=80;
 	}else if (strstr(fmtp,"ptime:90")!=NULL){
 		s->ptime=100; /* not allowed */
 	}else if (strstr(fmtp,"ptime:100")!=NULL){
 		s->ptime=100;
+	}else if (strstr(fmtp,"ptime:110")!=NULL){
+		s->ptime=120;
 	}else if (strstr(fmtp,"ptime:120")!=NULL){
 		s->ptime=120;
+	}else if (strstr(fmtp,"ptime:130")!=NULL){
+		s->ptime=140;
 	}else if (strstr(fmtp,"ptime:140")!=NULL){
 		s->ptime=140;
 	}
@@ -416,7 +426,7 @@ typedef struct DecState{
 } DecState;
 
 static void dec_init(MSFilter *f){
-	DecState *s=ms_new(DecState,1);
+	DecState *s=(DecState *)ms_new(DecState,1);
 	s->rate=8000;
 	s->frsz=0;
 	s->state=NULL;
