@@ -34,7 +34,6 @@ void ms_ticker_start(MSTicker *s){
 void ms_ticker_init(MSTicker *ticker)
 {
 	ms_mutex_init(&ticker->lock,NULL);
-	ms_cond_init(&ticker->cond,NULL);
 	ticker->execution_list=NULL;
 	ticker->ticks=1;
 	ticker->time=0;
@@ -50,7 +49,7 @@ void ms_ticker_init(MSTicker *ticker)
 }
 
 MSTicker *ms_ticker_new(){
-	MSTicker *obj=ms_new(MSTicker,1);
+	MSTicker *obj=(MSTicker *)ms_new(MSTicker,1);
 	ms_ticker_init(obj);
 	return obj;
 }
@@ -58,7 +57,6 @@ MSTicker *ms_ticker_new(){
 void ms_ticker_stop(MSTicker *s){
 	ms_mutex_lock(&s->lock);
 	s->run=FALSE;
-	ms_cond_wait(&s->cond,&s->lock);
 	ms_mutex_unlock(&s->lock);
 	ms_thread_join(s->thread,NULL);
 }
@@ -68,7 +66,6 @@ void ms_ticker_uninit(MSTicker *ticker)
 {
 	ms_ticker_stop(ticker);
 	ms_mutex_destroy(&ticker->lock);
-	ms_cond_destroy(&ticker->cond);
 }
 
 void ms_ticker_destroy(MSTicker *ticker){
@@ -246,6 +243,10 @@ static uint64_t get_cur_time(void *unused){
 	return timemillis;
 #elif defined(WIN32)
 	return timeGetTime() ;
+#elif defined(__MACH__) && defined(__GNUC__) && (__GNUC__ >= 3)
+	struct timeval tv;
+	gettimeofday(&tv, NULL);
+	return (tv.tv_sec*1000LL) + (tv.tv_usec/1000LL);
 #elif defined(__MACH__)
 	struct timespec ts;
 	struct timeb time_val;
@@ -317,11 +318,13 @@ static void unset_high_prio(int precision){
 
 void * ms_ticker_run(void *arg)
 {
-	MSTicker *s=(MSTicker*)arg;
 	uint64_t realtime;
+	int64_t diff;
+	MSTicker *s=(MSTicker*)arg;
 	int lastlate=0;
 	int precision=2;
-
+	int late;
+	
 	precision = set_high_prio();
 
 
@@ -334,7 +337,6 @@ void * ms_ticker_run(void *arg)
 		run_graphs(s,s->execution_list,FALSE);
 		s->time+=s->interval;
 		while(1){
-			int64_t diff;
 			realtime=s->get_cur_time_ptr(s->get_cur_time_data)-s->orig;
 			ms_mutex_unlock(&s->lock);
 			diff=s->time-realtime;
@@ -342,7 +344,7 @@ void * ms_ticker_run(void *arg)
 				/* sleep until next tick */
 				sleepMs(diff);
 			}else{
-				int late=-diff;
+				late=-diff;
 				if (late>s->interval*5 && late>lastlate){
 					ms_warning("We are late of %d miliseconds.",late);
 				}
@@ -353,10 +355,10 @@ void * ms_ticker_run(void *arg)
 		}
 		ms_mutex_lock(&s->lock);
 	}
-	ms_cond_signal(&s->cond);
 	ms_mutex_unlock(&s->lock);
 	unset_high_prio(precision);
 	ms_message("MSTicker thread exiting");
+
 	ms_thread_exit(NULL);
 	return NULL;
 }
@@ -396,7 +398,6 @@ void * ms_ticker_run(void *arg)
 
 		ms_mutex_lock(&s->lock);
 	}
-	ms_cond_signal(&s->cond);
 	ms_mutex_unlock(&s->lock);
 	timeKillEvent (timerId);
 	CloseHandle (s->TimeEvent);
