@@ -18,6 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "mediastreamer2/msfilter.h"
+#include "mediastreamer2/msticker.h"
 #include "mediastreamer2/msvideo.h"
 
 #include <ffmpeg/avcodec.h>
@@ -29,6 +30,11 @@ typedef struct SizeConvState{
 	YuvBuf outbuf;
 	struct SwsContext *sws_ctx;
 	mblk_t *om;
+
+	float fps;
+	float start_time;
+	int frame_count;
+	queue_t rq;
 } SizeConvState;
 
 
@@ -43,6 +49,10 @@ static void size_conv_init(MSFilter *f){
 	s->in_vsize.height=0;
 	s->sws_ctx=NULL;
 	s->om=NULL;
+	s->start_time=0;
+	s->frame_count=-1;
+	s->fps=-1; /* default to process ALL frames */
+	qinit(&s->rq);
 	f->data=s;
 }
 
@@ -61,6 +71,7 @@ static void size_conv_postprocess(MSFilter *f){
 		freemsg(s->om);
 		s->om=NULL;
 	}
+	flushq(&s->rq,0);
 }
 
 static mblk_t *size_conv_alloc_mblk(SizeConvState *s){
@@ -99,8 +110,39 @@ static void size_conv_process(MSFilter *f){
 	SizeConvState *s=(SizeConvState*)f->data;
 	YuvBuf inbuf;
 	mblk_t *im;
+	int cur_frame;
+
 	ms_filter_lock(f);
+
+	if (s->frame_count==-1){
+		s->start_time=f->ticker->time;
+		s->frame_count=0;
+	}
 	while((im=ms_queue_get(f->inputs[0]))!=NULL ){
+		putq(&s->rq, im);
+	}
+
+	cur_frame=((f->ticker->time-s->start_time)*s->fps/1000.0);
+	if (cur_frame<=s->frame_count && s->fps>=0) {
+		/* too much frame */
+		while(s->rq.q_mcount>1){
+			ms_message("MSSizeConv: extra frame removed.");
+			im=getq(&s->rq);
+			freemsg(im);
+		}
+		ms_filter_unlock(f);
+		return;
+	}
+
+	if (cur_frame>s->frame_count && s->fps>=0) {
+		/*keep the most recent frame if several frames have been captured */
+		while(s->rq.q_mcount>1){
+			ms_message("MSSizeConv: extra frame removed.");
+			im=getq(&s->rq);
+			freemsg(im);
+		}
+	}
+	while((im=getq(&s->rq))!=NULL ){
 		if (yuv_buf_init_from_mblk(&inbuf,im)==0){
 			if (inbuf.w==s->target_vsize.width &&
 				inbuf.h==s->target_vsize.height){
@@ -115,8 +157,10 @@ static void size_conv_process(MSFilter *f){
 				ms_queue_put(f->outputs[0],om);
 				freemsg(im);
 			}
+			s->frame_count++;
 		}else freemsg(im);
 	}
+
 	ms_filter_unlock(f);
 }
 
@@ -135,9 +179,16 @@ static int sizeconv_set_vsize(MSFilter *f, void*arg){
 	return 0;
 }
 
+static int sizeconv_set_fps(MSFilter *f, void *arg){
+	SizeConvState *s=(SizeConvState*)f->data;
+	s->fps=*((float*)arg);
+	s->frame_count=-1; /* reset counter used for fps */
+	return 0;
+}
 
 
 static MSFilterMethod methods[]={
+	{	MS_FILTER_SET_FPS	,	sizeconv_set_fps	},
 	{	MS_FILTER_SET_VIDEO_SIZE, sizeconv_set_vsize	},
 	{	0	,	NULL }
 };
