@@ -62,12 +62,13 @@ static void enc_init(MSFilter *f){
 	s->packed_conf=NULL;
 	s->start_time=0;
 	s->conf_time=0;
-	s->mtu=1400;
+	s->mtu=ms_get_payload_max_size()-6;
 	f->data=s;
 }
 
 static void enc_uninit(MSFilter *f){
 	EncState *s=(EncState*)f->data;
+	theora_info_clear(&s->tinfo);
 	ms_free(s);
 }
 
@@ -237,7 +238,11 @@ static void enc_preprocess(MSFilter *f){
 static void enc_postprocess(MSFilter *f){
 	EncState *s=(EncState*)f->data;
 	theora_clear(&s->tstate);
-	theora_info_clear(&s->tinfo);
+	
+	//If preprocess is called after postprocess,
+	//then we loose all info...
+	//theora_info_clear(&s->tinfo);
+	
 	if (s->packed_conf) {
 		freemsg(s->packed_conf);
 		s->packed_conf=NULL;
