@@ -18,6 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include <ffmpeg/avcodec.h>
+#include <ffmpeg/swscale.h>
 
 #include "mediastreamer2/msfilter.h"
 #include "mediastreamer2/msvideo.h"
@@ -31,23 +32,18 @@ typedef struct DecState{
 	AVCodec *av_codec;
 	enum CodecID codec;
 	mblk_t *input;
+	YuvBuf outbuf;
 	mblk_t *yuv_msg;
+	struct SwsContext *sws_ctx;
 	int output_pix_fmt;
-	MSVideoSize vsize;
 	uint8_t dci[512];
 	int dci_size;
+	bool_t snow_initialized;
 }DecState;
 
 
-static int dec_set_vsize(MSFilter *f, void *arg){
-	DecState *s=(DecState*)f->data;
-	MSVideoSize *vsize=(MSVideoSize*)arg;
-	s->vsize=*vsize;
-	return 0;
-}
-
 static void dec_init(MSFilter *f, enum CodecID cid){
-	DecState *s=ms_new0(DecState,1);
+	DecState *s=(DecState *)ms_new0(DecState,1);
 	ms_ffmpeg_check_init();
 	
 	avcodec_get_context_defaults(&s->av_context);
@@ -55,11 +51,21 @@ static void dec_init(MSFilter *f, enum CodecID cid){
 	s->codec=cid;
 	s->input=NULL;
 	s->yuv_msg=NULL;
-	s->vsize.width = MS_VIDEO_SIZE_CIF_W;
-	s->vsize.height = MS_VIDEO_SIZE_CIF_H;
 	s->output_pix_fmt=PIX_FMT_YUV420P;
+	s->snow_initialized=FALSE;
+	s->outbuf.w=0;
+	s->outbuf.h=0;
+	s->sws_ctx=NULL;
 	f->data=s;
-	
+
+	s->av_codec=avcodec_find_decoder(s->codec);
+	if (s->av_codec==NULL){
+		ms_error("Could not find decoder %i!",s->codec);
+	}
+	/*
+	s->av_context.width=MS_VIDEO_SIZE_QCIF_W;
+	s->av_context.height=MS_VIDEO_SIZE_QCIF_H;
+	*/
 }
 
 static void dec_h263_init(MSFilter *f){
@@ -71,13 +77,28 @@ static void dec_mpeg4_init(MSFilter *f){
 }
 
 static void dec_mjpeg_init(MSFilter *f){
-	dec_init(f,CODEC_ID_MJPEG);
+	DecState *s;
+	dec_init(f,CODEC_ID_JPEGLS);
+	s=(DecState*)f->data;
+	if (s->av_codec==NULL){
+		/*retry with mjpeg*/
+		ms_error("JPEGLS codec not found, retrying with MJPEG...");
+		dec_init(f,CODEC_ID_MJPEG);
+	}
+}
+
+static void dec_snow_init(MSFilter *f){
+	dec_init(f,CODEC_ID_SNOW);
 }
 
 static void dec_uninit(MSFilter *f){
 	DecState *s=(DecState*)f->data;
 	if (s->input!=NULL) freemsg(s->input);
 	if (s->yuv_msg!=NULL) freemsg(s->yuv_msg);
+	if (s->sws_ctx!=NULL){
+		sws_freeContext(s->sws_ctx);
+		s->sws_ctx=NULL;
+	}
 	ms_free(s);
 }
 
@@ -104,16 +125,14 @@ static int dec_add_fmtp(MSFilter *f, void *data){
 static void dec_preprocess(MSFilter *f){
 	DecState *s=(DecState*)f->data;
 	int error;
-	s->av_codec=avcodec_find_decoder(s->codec);
-	if (s->av_codec==NULL){
-		ms_error("Could not find decoder !");
-		return;
-	}
-	error=avcodec_open(&s->av_context, s->av_codec);
-	if (error!=0) ms_error("avcodec_open() failed: %i",error);
-	if (s->codec==CODEC_ID_MPEG4 && s->dci_size>0){
-		s->av_context.extradata=s->dci;
-		s->av_context.extradata_size=s->dci_size;
+	/* we must know picture size before initializing snow decoder*/
+	if (s->codec!=CODEC_ID_SNOW){
+		error=avcodec_open(&s->av_context, s->av_codec);
+		if (error!=0) ms_error("avcodec_open() failed: %i",error);
+		if (s->codec==CODEC_ID_MPEG4 && s->dci_size>0){
+			s->av_context.extradata=s->dci;
+			s->av_context.extradata_size=s->dci_size;
+		}
 	}
 }
 
@@ -125,20 +144,6 @@ static void dec_postprocess(MSFilter *f){
 	}
 }
 
-static mblk_t * dec_get_yuv(DecState *s){
-	int size=avpicture_get_size(s->output_pix_fmt,
-		s->av_context.width,s->av_context.height);
-	if (s->yuv_msg!=NULL && msgdsize(s->yuv_msg)<size){
-		freemsg(s->yuv_msg);
-		s->yuv_msg=NULL;/* need to create larger one */
-	}
-	if (s->yuv_msg==NULL){
-		s->yuv_msg=allocb(size, 0);
-	}
-	s->yuv_msg->b_wptr=s->yuv_msg->b_rptr+size;
-	return dupmsg(s->yuv_msg);
-}
-
 static mblk_t * skip_rfc2429_header(mblk_t *inm){
 	if (msgdsize(inm) >= 2){
 		uint32_t *p = (uint32_t*)inm->b_rptr;
@@ -172,23 +177,50 @@ static mblk_t * skip_rfc2429_header(mblk_t *inm){
 	return NULL;
 }
 
-static mblk_t *get_as_yuvmsg(DecState *s, AVFrame *orig){
-	AVPicture sent;
-	AVCodecContext *ctx=&s->av_context;
-	mblk_t *yuv;
-	/* set the image in the wanted format */
-	yuv=dec_get_yuv(s);
-	avpicture_fill(&sent,(uint8_t*)yuv->b_rptr,s->output_pix_fmt,ctx->width,ctx->height);
-	if (s->output_pix_fmt!=ctx->pix_fmt){
-		if (img_convert(&sent,s->output_pix_fmt,(AVPicture*)orig,ctx->pix_fmt,ctx->width,ctx->height) < 0) {
-			ms_error("Fail to convert to YUV420 pixel format.");
-			freemsg(yuv);
-			return NULL;
+static mblk_t * parse_snow_header(DecState *s,mblk_t *inm){
+	if (msgdsize(inm) >= 4){
+		uint32_t h = ntohl(*(uint32_t*)inm->b_rptr);
+		if (!s->snow_initialized){
+			int error;
+			s->av_context.width=h>>16;
+			s->av_context.height=h&0xffff;
+			error=avcodec_open(&s->av_context, s->av_codec);
+			if (error!=0) ms_error("avcodec_open() failed for snow: %i",error);
+			else {
+				s->snow_initialized=TRUE;
+				ms_message("Snow decoder initialized,size=%ix%i",
+				s->av_context.width,
+				s->av_context.height);
+			}
 		}
-	}else{
-		img_copy(&sent,(AVPicture*)orig,s->output_pix_fmt,ctx->width,ctx->height);
+		inm->b_rptr+=4;
+		return inm;
+	}else {
+		freemsg(inm);
+		return NULL;
 	}
-	return yuv;
+}
+
+static mblk_t *get_as_yuvmsg(MSFilter *f, DecState *s, AVFrame *orig){
+	AVCodecContext *ctx=&s->av_context;
+
+	if (s->outbuf.w!=ctx->width || s->outbuf.h!=ctx->height){
+		if (s->sws_ctx!=NULL){
+			sws_freeContext(s->sws_ctx);
+			s->sws_ctx=NULL;
+		}
+		s->yuv_msg=yuv_buf_alloc(&s->outbuf,ctx->width,ctx->height);
+		s->outbuf.w=ctx->width;
+		s->outbuf.h=ctx->height;
+		s->sws_ctx=sws_getContext(ctx->width,ctx->height,ctx->pix_fmt,
+			ctx->width,ctx->height,s->output_pix_fmt,SWS_FAST_BILINEAR,
+                	NULL, NULL, NULL);
+	}
+	if (sws_scale(s->sws_ctx,orig->data,orig->linesize, 0,
+					0, s->outbuf.planes, s->outbuf.strides)!=0){
+		ms_error("%s: error in sws_scale().",f->desc->name);
+	}
+	return dupmsg(s->yuv_msg);
 }
 
 static void dec_process_frame(MSFilter *f, mblk_t *inm){
@@ -198,6 +230,7 @@ static void dec_process_frame(MSFilter *f, mblk_t *inm){
 	/* get a picture from the input queue */
 	
 	if (s->codec==CODEC_ID_H263) inm=skip_rfc2429_header(inm);
+	else if (s->codec==CODEC_ID_SNOW && s->input==NULL) inm=parse_snow_header(s,inm);
 	if (inm){
 		/* accumulate the video packet until we have the rtp markbit*/
 		if (s->input==NULL){
@@ -221,8 +254,8 @@ static void dec_process_frame(MSFilter *f, mblk_t *inm){
 					ms_warning("ms_AVdecoder_process: error %i.",len);
 					break;
 				}
-				if (got_picture) {				
-					ms_queue_put(f->outputs[0],get_as_yuvmsg(s,&orig));
+				if (got_picture) {
+					ms_queue_put(f->outputs[0],get_as_yuvmsg(f,s,&orig));
 				}
 				frame->b_rptr+=len;
 			}
@@ -240,7 +273,6 @@ static void dec_process(MSFilter *f){
 
 
 static MSFilterMethod methods[]={
-	{		MS_FILTER_SET_VIDEO_SIZE	,	dec_set_vsize	},
 	{		MS_FILTER_ADD_FMTP		,	dec_add_fmtp	},
 	{		0		,		NULL			}
 };
@@ -295,6 +327,22 @@ MSFilterDesc ms_mjpeg_dec_desc={
 	methods
 };
 
+MSFilterDesc ms_snow_dec_desc={
+	MS_SNOW_DEC_ID,
+	"MSSnowDec",
+	"A snow decoder using ffmpeg library",
+	MS_FILTER_DECODER,
+	"snow",
+	1,
+	1,
+	dec_snow_init,
+	dec_preprocess,
+	dec_process,
+	dec_postprocess,
+	dec_uninit,
+	methods
+};
+
 #else
 
 MSFilterDesc ms_h263_dec_desc={
@@ -345,8 +393,25 @@ MSFilterDesc ms_mjpeg_dec_desc={
 	.methods= methods
 };
 
+MSFilterDesc ms_snow_dec_desc={
+	.id=MS_SNOW_DEC_ID,
+	.name="MSSnowDec",
+	.text="A snow decoder using ffmpeg library",
+	.category=MS_FILTER_DECODER,
+	.enc_fmt="x-snow",
+	.ninputs=1,
+	.noutputs=1,
+	.init=dec_snow_init,
+	.preprocess=dec_preprocess,
+	.process=dec_process,
+	.postprocess=dec_postprocess,
+	.uninit=dec_uninit,
+	.methods= methods
+};
+
 #endif
 
 MS_FILTER_DESC_EXPORT(ms_mpeg4_dec_desc)
 MS_FILTER_DESC_EXPORT(ms_h263_dec_desc)
 MS_FILTER_DESC_EXPORT(ms_mjpeg_dec_desc)
+MS_FILTER_DESC_EXPORT(ms_snow_dec_desc)
