@@ -22,6 +22,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer2/msvideo.h"
 #include "mediastreamer2/msrtp.h"
 #include "mediastreamer2/msv4l.h"
+#if (defined(WIN32) || defined(_WIN32_WCE))
+/* avoid double declaration of ms_win_display_desc */
+#define MS_VIDEO_OUT_HANDLE_RESIZING MS_FILTER_METHOD_NO_ARG(MS_VIDEO_OUT_ID,1)
+#else
+#include "mediastreamer2/msvideoout.h"
+#endif
 
 #ifdef HAVE_CONFIG_H
 #include "mediastreamer-config.h"
@@ -52,8 +58,6 @@ void video_stream_free (VideoStream * stream)
 		ms_filter_destroy(stream->pixconv);
 	if (stream->tee!=NULL)
 		ms_filter_destroy(stream->tee);
-	if (stream->sizeconv!=NULL)
-		ms_filter_destroy(stream->sizeconv);
 	if (stream->ticker != NULL)
 		ms_ticker_destroy (stream->ticker);
 	ms_free (stream);
@@ -73,14 +77,14 @@ void video_stream_change_decoder(VideoStream *stream, int payload){
 		MSFilter *dec=ms_filter_create_decoder(pt->mime_type);
 		if (dec!=NULL){
 			ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
-			ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
+			ms_filter_unlink(stream->decoder,0,stream->output,0);
 			ms_filter_postprocess(stream->decoder);
 			ms_filter_destroy(stream->decoder);
 			stream->decoder=dec;
 			if (pt->recv_fmtp!=NULL)
 				ms_filter_call_method(stream->decoder,MS_FILTER_ADD_FMTP,(void*)pt->recv_fmtp);
 			ms_filter_link (stream->rtprecv, 0, stream->decoder, 0);
-			ms_filter_link (stream->decoder,0 , stream->sizeconv, 0);
+			ms_filter_link (stream->decoder,0 , stream->output, 0);
 			ms_filter_preprocess(stream->decoder,stream->ticker);
 			
 		}else{
@@ -92,6 +96,9 @@ void video_stream_change_decoder(VideoStream *stream, int payload){
 }
 
 void video_stream_iterate(VideoStream *stream){
+	if (stream->output!=NULL)
+		ms_filter_call_method_noarg(stream->output,
+			MS_VIDEO_OUT_HANDLE_RESIZING);
 }
 
 static void payload_type_changed(RtpSession *session, unsigned long data){
@@ -149,7 +156,6 @@ int video_stream_start (VideoStream *stream, RtpProfile *profile, const char *re
 	/* creates the filters */
 	stream->source = ms_filter_new(MS_V4L_ID);
 	stream->tee = ms_filter_new(MS_TEE_ID);
-	stream->sizeconv = ms_filter_new(MS_SIZE_CONV_ID);
 	stream->output=ms_filter_new(MS_VIDEO_OUT_ID);
 
 	
@@ -188,8 +194,7 @@ int video_stream_start (VideoStream *stream, RtpProfile *profile, const char *re
 	vsize.height=MS_VIDEO_SIZE_CIF_H;
 	vsize.width=MS_VIDEO_SIZE_CIF_W;
 
-	ms_filter_call_method(stream->sizeconv,MS_FILTER_SET_PIX_FMT,&format);
-	ms_filter_call_method(stream->sizeconv,MS_FILTER_SET_VIDEO_SIZE,&vsize);
+	ms_filter_call_method(stream->output,MS_FILTER_SET_VIDEO_SIZE,&vsize);
 	ms_filter_call_method(stream->output,MS_FILTER_SET_PIX_FMT,&format);
 
 	if (pt->recv_fmtp!=NULL)
@@ -202,8 +207,7 @@ int video_stream_start (VideoStream *stream, RtpProfile *profile, const char *re
 	ms_filter_link (stream->encoder,0, stream->rtpsend,0);
 	
 	ms_filter_link (stream->rtprecv, 0, stream->decoder, 0);
-	ms_filter_link (stream->decoder,0 , stream->sizeconv, 0);
-	ms_filter_link (stream->sizeconv, 0, stream->output, 0);
+	ms_filter_link (stream->decoder,0 , stream->output, 0);
 	/* the source video must be send for preview */
 	ms_filter_link(stream->tee,1,stream->output,1);
 
@@ -233,8 +237,7 @@ video_stream_stop (VideoStream * stream)
 		ms_filter_unlink(stream->tee,0,stream->encoder,0);
 		ms_filter_unlink(stream->encoder, 0, stream->rtpsend,0);
 		ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
-		ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
-		ms_filter_unlink(stream->sizeconv,0,stream->output,0);
+		ms_filter_unlink(stream->decoder,0,stream->output,0);
 		ms_filter_unlink(stream->tee,1,stream->output,1);
 	}
 	video_stream_free (stream);
@@ -408,8 +411,6 @@ int video_stream_recv_only_start (VideoStream *stream, RtpProfile *profile, cons
 		ms_error("videostream.c: No codecs available for payload %i:%s.",payload,pt->mime_type);
 		return -1;
 	}
-
-	stream->sizeconv = ms_filter_new(MS_SIZE_CONV_ID);
 	stream->output=ms_filter_new(MS_VIDEO_OUT_ID);
 
 	/*force the decoder to output YUV420P */
@@ -420,8 +421,6 @@ int video_stream_recv_only_start (VideoStream *stream, RtpProfile *profile, cons
 	ms_message("Setting output vsize=%ix%i",vsize.width,vsize.height);
 	
 	ms_filter_call_method(stream->decoder,MS_FILTER_SET_PIX_FMT,&format);
-	ms_filter_call_method(stream->sizeconv,MS_FILTER_SET_PIX_FMT,&format);
-	ms_filter_call_method(stream->sizeconv,MS_FILTER_SET_VIDEO_SIZE,&vsize);
 	ms_filter_call_method(stream->output,MS_FILTER_SET_PIX_FMT,&format);
 	ms_filter_call_method(stream->output,MS_FILTER_SET_VIDEO_SIZE,&vsize);
 
@@ -432,8 +431,7 @@ int video_stream_recv_only_start (VideoStream *stream, RtpProfile *profile, cons
 
 	/* and then connect all */
 	ms_filter_link (stream->rtprecv, 0, stream->decoder, 0);
-	ms_filter_link (stream->decoder,0 , stream->sizeconv, 0);
-	ms_filter_link (stream->sizeconv, 0, stream->output, 0);
+	ms_filter_link (stream->decoder,0 , stream->output, 0);
 
 	/* create the ticker */
 	stream->ticker = ms_ticker_new(); 
@@ -447,8 +445,7 @@ void video_stream_recv_only_stop (VideoStream * stream){
 		ms_ticker_detach(stream->ticker, stream->rtprecv);
 		rtp_stats_display(rtp_session_get_stats(stream->session),"Video session's RTP statistics");
 		ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
-		ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
-		ms_filter_unlink(stream->sizeconv,0,stream->output,0);
+		ms_filter_unlink(stream->decoder,0,stream->output,0);
 	}
 	video_stream_free (stream);
 }
