@@ -57,7 +57,10 @@ typedef struct WinSndData{
 
     int sound_err;
     WAVEFORMATEX wfx;
-    WAVEHDR waveouthdr[30];
+#ifdef CONTROLVOLUME
+	DWORD dwOldVolume;
+#endif
+	WAVEHDR waveouthdr[30];
     char waveoutbuffer[30][3200];
     HWAVEOUT waveoutdev;
     int buffer_playing;
@@ -230,6 +233,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
 	device->wfx.nSamplesPerSec = rate; /* 8000; */
 	device->wfx.wBitsPerSample = bits;
 	
+
     dwFlag = CALLBACK_FUNCTION;
     if (devnumber != WAVE_MAPPER)
         dwFlag = WAVE_MAPPED | CALLBACK_FUNCTION;
@@ -248,8 +252,52 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
         return -1;
     }
 
-    /* prepare windows buffers */
+#if 0
+#define MM_WOM_SETSECONDARYGAINCLASS   (WM_USER)
+#define MM_WOM_SETSECONDARYGAINLIMIT   (WM_USER+1)
+#define MM_WOM_FORCESPEAKER            (WM_USER+2)
 
+	bool bSpeaker=TRUE;
+	mr = waveOutMessage(device->waveoutdev, MM_WOM_FORCESPEAKER, bSpeaker, 0);
+    if (mr != NOERROR)
+    {
+        ms_warning("Failed to use earphone. (waveOutMessage:0x%i)", mr);
+        return -1;
+    }
+
+	typedef HRESULT (* _SetSpeakerMode)(DWORD mode);
+	_SetSpeakerMode pfnSetSpeakerMode;
+
+	HINSTANCE hDll = LoadLibrary(L"\\windows\\ossvcs.dll");
+	//_debug(L"ossvcs.dll h=%X",hDll);
+	pfnSetSpeakerMode = (_SetSpeakerMode)GetProcAddress(hDll,(LPCTSTR)218);
+	if (pfnSetSpeakerMode)
+	{
+	//_debug(L"SetSpeakerMode imported.");
+	DWORD sm = 0;
+	//_debug(L"SpeakerMode set to %d", sm);
+	pfnSetSpeakerMode(sm);
+	}
+	//else
+	//_debug(L"pfnSetSpeakerMode import failed.");
+	FreeLibrary(hDll);
+#endif
+
+#ifdef CONTROLVOLUME
+	mr = waveOutGetVolume(device->waveoutdev, &device->dwOldVolume);
+    if (mr != NOERROR)
+    {
+        ms_warning("Failed to get volume device. (waveOutGetVolume:0x%i)", mr);
+    }
+
+	mr = waveOutSetVolume(device->waveoutdev, 0xFFFFFFFF);
+    if (mr != NOERROR)
+    {
+        ms_warning("Failed to set volume device. (waveOutSetVolume:0x%i)", mr);
+    }
+#endif
+
+    /* prepare windows buffers */
 
     for (i = 0; i < MAX_WAVEHDR; i++)
     {
@@ -519,7 +567,6 @@ static MSSndCard *winsnd_card_new(const char *pcmdev, const char *mixdev, int id
 static void winsnd_detect(MSSndCardManager *m){
     MMRESULT mr = NOERROR;
     unsigned int nInDevices = waveInGetNumDevs ();
-    /*unsigned int nOutDevices = waveOutGetNumDevs ();*/
     unsigned int item;
 	char pcmdev[1024];
 	char mixdev[1024];
@@ -542,6 +589,19 @@ static void winsnd_detect(MSSndCardManager *m){
 			ms_snd_card_manager_add_card(m,card);
         }
     }
+#if 0
+	nInDevices = mixerGetNumDevs ();
+    for (item = 0; item < nInDevices; item++)
+    {
+        MIXERCAPS caps;
+        mr = mixerGetDevCaps (item, &caps, sizeof (MIXERCAPS));
+        if (mr == MMSYSERR_NOERROR)
+        {
+	        snprintf(pcmdev,sizeof(pcmdev),"%s",caps.szPname);
+	        snprintf(mixdev,sizeof(mixdev),"%s",caps.szPname);
+        }
+    }
+#endif
 }
 
 static void * winsnd_thread(void *p){
@@ -755,6 +815,9 @@ static void winsnd_stop_w(MSSndCard *card){
 	if (d->read_started==FALSE){
 		ms_thread_join(d->thread,NULL);
 	}
+#ifdef CONTROLVOLUME
+	waveOutSetVolume(d->waveoutdev, d->dwOldVolume);
+#endif
 }
 
 static mblk_t *winsnd_get(MSSndCard *card){
