@@ -29,6 +29,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define WINSND_NBUFS 10
 #define WINSND_NSAMPLES 160
+#define WINSND_MINIMUMBUFFER 5
 
 static MSFilter *ms_winsnd_read_new(MSSndCard *card);
 static MSFilter *ms_winsnd_write_new(MSSndCard *card);
@@ -91,7 +92,7 @@ static void winsndcard_set_source(MSSndCard *card, MSSndCardCapture source){
 }
 
 static void winsndcard_init(MSSndCard *card){
-	WinSndCard *c=ms_new(WinSndCard,1);
+	WinSndCard *c=(WinSndCard *)ms_new(WinSndCard,1);
 	card->data=c;
 }
 
@@ -206,7 +207,7 @@ static uint64_t winsnd_get_cur_time( void *data){
 
 
 static void winsnd_init(MSFilter *f){
-	WinSnd *d=ms_new0(WinSnd,1);
+	WinSnd *d=(WinSnd *)ms_new0(WinSnd,1);
 	d->wfx.wFormatTag = WAVE_FORMAT_PCM;
 	d->wfx.cbSize = 0;
 	d->wfx.nAvgBytesPerSec = 16000;
@@ -221,7 +222,7 @@ static void winsnd_init(MSFilter *f){
 	d->stat_input=0;
 	d->stat_output=0;
 	d->stat_notplayed=0;
-	d->stat_minimumbuffer=5;
+	d->stat_minimumbuffer=WINSND_MINIMUMBUFFER;
 }
 
 static void winsnd_uninit(MSFilter *f){
@@ -239,9 +240,9 @@ static void add_input_buffer(WinSnd *d, WAVEHDR *hdr, int buflen){
 	hdr->lpData=(LPSTR)m->b_wptr;
 	hdr->dwBufferLength=buflen;
 	hdr->dwFlags = 0;
-    hdr->dwUser = (DWORD)m;
-    mr = waveInPrepareHeader (d->indev,hdr,sizeof(*hdr));
-    if (mr != MMSYSERR_NOERROR){
+	hdr->dwUser = (DWORD)m;
+	mr = waveInPrepareHeader (d->indev,hdr,sizeof(*hdr));
+	if (mr != MMSYSERR_NOERROR){
 		ms_error("waveInPrepareHeader() error");
 		return ;
 	}
@@ -289,7 +290,7 @@ read_callback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
 #endif
 			}
 
-			ms_debug("read_callback : WIM_DATA (%p,%i)",wHdr,bsize);
+			/* ms_warning("read_callback : WIM_DATA (%p,%i)",wHdr,bsize); */
 			m=(mblk_t*)wHdr->dwUser;
 			m->b_wptr+=bsize;
 			wHdr->dwUser=0;
@@ -313,18 +314,18 @@ static void winsnd_read_preprocess(MSFilter *f){
 	MMRESULT mr;
 	int i;
 	int bsize;
-    DWORD dwFlag;
+	DWORD dwFlag;
 
 	d->stat_input=0;
 	d->stat_output=0;
 	d->stat_notplayed=0;
-	d->stat_minimumbuffer=5;
+	d->stat_minimumbuffer=WINSND_MINIMUMBUFFER;
 
 	winsnd_apply_settings(d);
 	/* Init Microphone device */
 	dwFlag = CALLBACK_FUNCTION;
-    if (d->dev_id != WAVE_MAPPER)
-        dwFlag = WAVE_MAPPED | CALLBACK_FUNCTION;
+	if (d->dev_id != WAVE_MAPPER)
+		dwFlag = WAVE_MAPPED | CALLBACK_FUNCTION;
 	mr = waveInOpen (&d->indev, d->dev_id, &d->wfx,
 	            (DWORD) read_callback, (DWORD)f, dwFlag);
 	if (mr != MMSYSERR_NOERROR)
@@ -372,11 +373,20 @@ static void winsnd_read_postprocess(MSFilter *f){
 	}
 	for(i=0;i<WINSND_NBUFS;++i){
 		WAVEHDR *hdr=&d->hdrs[i];
-		mr = waveInUnprepareHeader(d->indev,hdr,sizeof (*hdr));
-		if (mr != MMSYSERR_NOERROR){
-			ms_error("waveInUnPrepareHeader() error");
+		if (hdr->dwFlags & WHDR_PREPARED)
+		{
+			mr = waveInUnprepareHeader(d->indev,hdr,sizeof (*hdr));
+			if (mr != MMSYSERR_NOERROR){
+				ms_error("waveInUnPrepareHeader() error");
+			}
 		}
 	}
+	mr = waveInClose(d->indev);
+	if (mr != MMSYSERR_NOERROR){
+		ms_error("waveInClose() error");
+		return ;
+	}
+
 	ms_message("Shutting down sound device (playing: %i) (input-output: %i) (notplayed: %i)", d->nbufs_playing, d->stat_input - d->stat_output, d->stat_notplayed);
 	flushq(&d->rq,0);
 }
@@ -430,24 +440,24 @@ write_callback(HWAVEOUT outdev, UINT uMsg, DWORD dwInstance,
 static void winsnd_write_preprocess(MSFilter *f){
 	WinSnd *d=(WinSnd*)f->data;
 	MMRESULT mr;
-    DWORD dwFlag;
+	DWORD dwFlag;
 	int i;
 
 	d->stat_input=0;
 	d->stat_output=0;
 	d->stat_notplayed=0;
-	d->stat_minimumbuffer=5;
+	d->stat_minimumbuffer=WINSND_MINIMUMBUFFER;
 
 	winsnd_apply_settings(d);
 	/* Init Microphone device */
 	dwFlag = CALLBACK_FUNCTION;
-    if (d->dev_id != WAVE_MAPPER)
-        dwFlag = WAVE_MAPPED | CALLBACK_FUNCTION;
+	if (d->dev_id != WAVE_MAPPER)
+		dwFlag = WAVE_MAPPED | CALLBACK_FUNCTION;
 	mr = waveOutOpen (&d->outdev, d->dev_id, &d->wfx,
 	            (DWORD) write_callback, (DWORD)d, dwFlag);
 	if (mr != MMSYSERR_NOERROR)
 	{
-	    ms_error("Failed to open windows sound device %i. (waveOutOpen:0x%i)",d->dev_id, mr);
+		ms_error("Failed to open windows sound device %i. (waveOutOpen:0x%i)",d->dev_id, mr);
 		mr = waveOutOpen (&d->outdev, WAVE_MAPPER, &d->wfx,
 					(DWORD) write_callback, (DWORD)d, CALLBACK_FUNCTION);
 		if (mr != MMSYSERR_NOERROR)
@@ -507,6 +517,11 @@ static void winsnd_write_process(MSFilter *f){
 		return;
 	}
 
+#ifdef AMD_HACK
+	/* too many sound card are crappy on windows... */
+	d->stat_minimumbuffer=15;
+#endif
+
 	if (d->nbufs_playing==0)
 		ms_warning("no buffer currently playing (q.m_count=%i), (playing: %i)", f->inputs[0]->q.q_mcount,  d->nbufs_playing);
 
@@ -560,7 +575,7 @@ static void winsnd_write_process(MSFilter *f){
 
 	if ( d->stat_output > 150
 		&& ((d->stat_notplayed*100)/d->stat_output) >10
-		&& d->stat_minimumbuffer<18)
+		&& d->stat_minimumbuffer<15)
 	{
 		d->stat_minimumbuffer+=6;
 		ms_message("Increasing sound card number of write buffer to %i", d->stat_minimumbuffer);
