@@ -144,6 +144,7 @@ int main(int argc, char * argv[])
 	rtp_profile_set_payload(&av_profile,97,&payload_type_theora);
 	rtp_profile_set_payload(&av_profile,99,&payload_type_mp4v);
 	rtp_profile_set_payload(&av_profile,100,&payload_type_x_snow);
+	rtp_profile_set_payload(&av_profile,102,&payload_type_h264);
 #endif
 	if (argc<4) {
 		printf(usage);
@@ -176,6 +177,7 @@ int main(int argc, char * argv[])
 			ec=TRUE;
 		}
 		
+		
 	}
 	run_media_streams(localport,ip,remoteport,payload,fmtp,jitter,ec,bitrate);
 	return 0;
@@ -224,20 +226,25 @@ void run_media_streams(int localport,  const char *remote_ip, int remoteport, in
 	rtp_session_register_event_queue(session,q);
 	while(cond)
 	{
-		/* sleep until we receive SIGINT */
-#ifdef WIN32
 		int n;
-        MSG msg;
-        for(n=0;n<100;++n){
-        	Sleep(10);
+        	for(n=0;n<100;++n){
+#ifdef WIN32
+			MSG msg;
+    		Sleep(10);
 			while (PeekMessage(&msg, NULL, 0, 0,1)){
-        		TranslateMessage(&msg);
-        		DispatchMessage(&msg);
+        			TranslateMessage(&msg);
+        			DispatchMessage(&msg);
 			}
-		}
 #else
-		sleep(1);
+			struct timespec ts;
+			ts.tv_sec=0;
+			ts.tv_nsec=10000000;
+			nanosleep(&ts,NULL);
 #endif
+#ifdef VIDEO_ENABLED
+			if (video) video_stream_iterate(video);
+#endif
+		}
 		ortp_global_stats_display();
 		if (session){
 			printf("Bandwidth usage: download=%f kbits/sec, upload=%f kbits/sec\n",
