@@ -27,12 +27,26 @@ int main(int argc, char *argv[]){
 
 	/* this is to test the sequence start/stop */
 	for(i=0;i<1;++i){
+		int n;
 		vs=video_preview_start(devname);
+
+        	for(n=0;n<1000;++n){
 #ifdef WIN32
-		Sleep(5000);
+        		Sleep(100);
+			MSG msg;
+			while (PeekMessage(&msg, NULL, 0, 0,1)){
+        			TranslateMessage(&msg);
+        			DispatchMessage(&msg);
+			}
 #else
-		sleep(5);
+			struct timespec ts;
+			ts.tv_sec=0;
+			ts.tv_nsec=10000000;
+			nanosleep(&ts,NULL);
+
+			if (vs) video_stream_iterate(vs);
 #endif
+		}
 		video_preview_stop(vs);
 	}
 	return 0;
