@@ -186,6 +186,8 @@ VAR_DECLSPEC PayloadType payload_type_h263_1998;
 VAR_DECLSPEC PayloadType payload_type_h263_2000;
 VAR_DECLSPEC PayloadType payload_type_mp4v;
 VAR_DECLSPEC PayloadType payload_type_theora;
+VAR_DECLSPEC PayloadType payload_type_h264;
+VAR_DECLSPEC PayloadType payload_type_t140;
 
 
 /* telephone-event */
