@@ -211,6 +211,15 @@ void* ortp_realloc(void *ptr, size_t sz);
 void* ortp_malloc0(size_t sz);
 char * ortp_strdup(const char *tmp);
 
+/*override the allocator with this method, to be called BEFORE ortp_init()*/
+typedef struct _OrtpMemoryFunctions{
+	void *(*malloc_fun)(size_t sz);
+	void *(*realloc_fun)(void *ptr, size_t sz);
+	void (*free_fun)(void *ptr);
+}OrtpMemoryFunctions;
+
+void ortp_set_memory_functions(OrtpMemoryFunctions *functions);
+
 #define ortp_new(type,count)	ortp_malloc(sizeof(type)*(count))
 #define ortp_new0(type,count)	ortp_malloc0(sizeof(type)*(count))
 
