@@ -25,7 +25,7 @@
 #include <ortp/str_utils.h>
 
 #define IPMAXLEN 20
-#define UDP_MAX_SIZE 65536
+#define UDP_MAX_SIZE 1500
 #define RTP_FIXED_HEADER_SIZE 12
 #define RTP_DEFAULT_JITTER_TIME 80	/*miliseconds*/
 #define RTP_DEFAULT_MULTICAST_TTL 5	/*hops*/
@@ -69,8 +69,6 @@ typedef struct rtp_stats
 	uint64_t packet_recv;	/* number of packets received */
 	uint64_t unavaillable;	/* packets not availlable when they were queried */
 	uint64_t outoftime;		/* number of packets that were received too late */
-	uint64_t skipped;		/* number of packets skipped (that the application never queried 
-											or that need to be skipped in order to compensate a clock slide (see adaptive jitter control)) */
 	uint64_t cum_packet_loss; /* cumulative number of packet lost */
 	uint64_t bad;			/* packets that did not appear to be RTP */
 	uint64_t discarded;		/* incoming packets discarded because the queue exceeds its max size */
@@ -101,6 +99,8 @@ void rtp_add_csrc(mblk_t *mp ,uint32_t csrc);
 #define rtp_get_seqnumber(mp)	(((rtp_header_t*)((mp)->b_rptr))->seq_number)
 #define rtp_get_payload_type(mp)	(((rtp_header_t*)((mp)->b_rptr))->paytype)
 #define rtp_get_ssrc(mp)		(((rtp_header_t*)((mp)->b_rptr))->ssrc)
+#define rtp_get_cc(mp)		(((rtp_header_t*)((mp)->b_rptr))->cc)
+#define rtp_get_csrc(mp, idx)		(((rtp_header_t*)((mp)->b_rptr))->csrc[idx])
 
 
 #endif
