@@ -177,10 +177,12 @@ struct _RtpSession
         struct {
 	  RtpProfile *profile;
 	  int pt;
-	  int ssrc;
+	  unsigned int ssrc;
 	  WaitPoint wp;
 	  int telephone_events_pt;	/* the payload type used for telephony events */
 	} snd,rcv;
+	unsigned int inc_ssrc_candidate;
+	int inc_same_ssrc_count;
 	int hw_recv_pt; /* recv payload type before jitter buffer */
 	int recv_buf_size;
 	RtpSignalTable on_ssrc_changed;
@@ -211,6 +213,7 @@ struct _RtpSession
 	bool_t symmetric_rtp;
 	bool_t permissive; /*use the permissive algorithm*/
 	bool_t use_connect; /* use connect() on the socket */
+	bool_t ssrc_set;
 };
 	
 
