@@ -380,6 +380,27 @@ PayloadType payload_type_theora={
 	CHANNELS(0)
 };
 
+PayloadType payload_type_h264={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("H264"),
+	CHANNELS(0)
+};
 
+PayloadType	payload_type_t140={
+	PAYLOAD_AUDIO_PACKETIZED, /*type */
+	1000,
+	0,
+	NULL,
+	0,
+	0,
+	"t140",
+	0,
+	0
+};
 
 
