@@ -31,7 +31,7 @@
 #include "rtpsession_priv.h"
 #include <math.h>
 
-#define JC_BETA 0.03	/*allows a clock slide around 3% */
+#define JC_BETA 0.01	
 #define JC_GAMMA (JC_BETA)
 
 #include "jitterctl.h"
@@ -89,14 +89,18 @@ void jitter_control_new_packet(JitterControl *ctl, uint32_t packet_ts, uint32_t
 	float gap;
 	int d;
 	//printf("diff=%g\n",diff);
-	
-	ctl->count++;
-	ctl->slide= (float) ((ctl->slide*(1-JC_BETA)) + ((float)diff*JC_BETA));
+	if (ctl->count==0){
+		ctl->slide=diff;
+		ctl->jitter=0;
+	}else{
+		ctl->slide= (float) ((ctl->slide*(1-JC_BETA)) + ((float)diff*JC_BETA));
+	}
 	gap=(float) fabs((float)diff - ctl->slide);
 	ctl->jitter=(float) ((ctl->jitter*(1-JC_GAMMA)) + (gap*JC_GAMMA));
 	d=diff-ctl->olddiff;
 	ctl->inter_jitter=(float) (ctl->inter_jitter+ (( (float)abs(d) - ctl->inter_jitter)*(1/16.0)));
 	ctl->olddiff=diff;
+	ctl->count++;
 	if (ctl->adaptive){
 		if (ctl->count%50==0) {
 			/*jitter_control_dump_stats(ctl);*/
