@@ -32,35 +32,61 @@
 #include <process.h>
 #endif
 
+static void *ortp_libc_malloc(size_t sz){
+	return malloc(sz);
+}
+
+static void *ortp_libc_realloc(void *ptr, size_t sz){
+	return realloc(ptr,sz);
+}
+
+static void ortp_libc_free(void*ptr){
+	free(ptr);
+}
+
+static bool_t allocator_used=FALSE;
+
+static OrtpMemoryFunctions ortp_allocator={
+	ortp_libc_malloc,
+	ortp_libc_realloc,
+	ortp_libc_free
+};
+
+void ortp_set_memory_functions(OrtpMemoryFunctions *functions){
+	if (allocator_used){
+		ortp_fatal("ortp_set_memory_functions() must be called before "
+		"first use of ortp_malloc or ortp_realloc");
+		return;
+	}
+	ortp_allocator=*functions;
+}
+
 void* ortp_malloc(size_t sz){
-    return malloc(sz);
+	allocator_used=TRUE;
+	return ortp_allocator.malloc_fun(sz);
 }
 
 void* ortp_realloc(void *ptr, size_t sz){
-    return realloc(ptr,sz);
+	allocator_used=TRUE;
+	return ortp_allocator.realloc_fun(ptr,sz);
+}
+
+void ortp_free(void* ptr){
+	ortp_allocator.free_fun(ptr);
 }
 
 void * ortp_malloc0(size_t size){
-	void *ptr=malloc(size);
+	void *ptr=ortp_malloc(size);
 	memset(ptr,0,size);
 	return ptr;
 }
 
 char * ortp_strdup(const char *tmp){
-#if	defined(_WIN32) || defined(_WIN32_WCE)
-    return _strdup(tmp);
-#elif defined(__APPLE_CC__)
-    if (tmp==NULL)
-      return NULL;
-    return strdup(tmp);
-#else
-    return strdup(tmp);
-#endif
-}
-
-
-void ortp_free(void* ptr){
-	free(ptr);
+	size_t sz=strlen(tmp)+1;
+	char *ret=(char*)ortp_malloc(sz);
+	strcpy(ret,tmp);
+	ret[sz-1]='\0';
+	return ret;
 }
 
 /*
