@@ -17,7 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
 #include "ortp-config-win32.h"
 #else
 #include "ortp-config.h"
@@ -26,7 +26,7 @@
 #include "ortp/ortp.h"
 #include "rtptimer.h"
 
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 
 #ifdef __linux__
 #include <sys/select.h>
@@ -63,7 +63,7 @@ void posix_timer_do()
 	{
 		tv.tv_sec = diff/1000;
 		tv.tv_usec = (diff%1000)*1000;
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
         /* this kind of select is not supported on windows */
 		Sleep(tv.tv_usec/1000 + tv.tv_sec * 1000);
 #else
