@@ -75,10 +75,14 @@ static mblk_t * sdes_chunk_pad(mblk_t *m){
 	return appendb(m,"",1,TRUE);
 }
 
+/**
+ * Set session's SDES item for automatic sending of RTCP compound packets.
+ * If some items are not specified, use NULL.
+**/
 void rtp_session_set_source_description(RtpSession *session, 
     const char *cname, const char *name, const char *email, const char *phone, 
     const char *loc, const char *tool, const char *note){
-	mblk_t *chunk = sdes_chunk_new(session->send_ssrc);
+	mblk_t *chunk = sdes_chunk_new(session->snd.ssrc);
 	mblk_t *m=chunk;
 	const char *_cname=cname;
 	if (_cname==NULL)
@@ -133,7 +137,7 @@ mblk_t* rtp_session_create_rtcp_sdes_packet(RtpSession *session)
 	mp->b_wptr+=sizeof(rtcp_common_header_t);
 	
 	/* concatenate all sdes chunks */
-	sdes_chunk_set_ssrc(session->sd,session->send_ssrc);
+	sdes_chunk_set_ssrc(session->sd,session->snd.ssrc);
 	m=concatb(m,dupmsg(session->sd));
 	rc++;
 	
@@ -248,7 +252,7 @@ static void report_block_init(report_block_t *b, RtpSession *session){
 		delay_snc_last_sr=(uint32_t) delay;
 	}
 	
-	b->ssrc=htonl(session->recv_ssrc);
+	b->ssrc=htonl(session->rcv.ssrc);
 	fl_cnpl=((loss_fraction&0xFF)<<24) | (stream->stats.cum_packet_loss & 0xFFFFFF);
 	b->fl_cnpl=htonl(fl_cnpl);
 	b->interarrival_jitter=htonl((uint32_t) stream->jittctl.inter_jitter);
@@ -261,19 +265,23 @@ static void report_block_init(report_block_t *b, RtpSession *session){
 
 static int rtcp_sr_init(RtpSession *session, uint8_t *buf, int size){
 	rtcp_sr_t *sr=(rtcp_sr_t*)buf;
-	if (size<sizeof(rtcp_sr_t)) return 0;
-	rtcp_common_header_init(&sr->ch,session,RTCP_SR,1,sizeof(rtcp_sr_t));
-	sr->ssrc=htonl(session->send_ssrc);
+	int rr=(session->rtp.stats.packet_recv>0);
+	int sr_size=sizeof(rtcp_sr_t)-sizeof(report_block_t)+(rr*sizeof(report_block_t));
+	if (size<sr_size) return 0;
+	rtcp_common_header_init(&sr->ch,session,RTCP_SR,rr,sr_size);
+	sr->ssrc=htonl(session->snd.ssrc);
 	sender_info_init(&sr->si,session);
-	report_block_init(&sr->rb[0],session);
-	return sizeof(rtcp_sr_t);
+	/*only include a report block if packets were received*/
+	if (rr)
+		report_block_init(&sr->rb[0],session);
+	return sr_size;
 }
 
 static int rtcp_rr_init(RtpSession *session, uint8_t *buf, int size){
 	rtcp_rr_t *rr=(rtcp_rr_t*)buf;
 	if (size<sizeof(rtcp_rr_t)) return 0;
 	rtcp_common_header_init(&rr->ch,session,RTCP_RR,1,sizeof(rtcp_rr_t));
-	rr->ssrc=htonl(session->send_ssrc);
+	rr->ssrc=htonl(session->snd.ssrc);
 	report_block_init(&rr->rb[0],session);
 	return sizeof(rtcp_rr_t);
 }
@@ -282,7 +290,7 @@ static int rtcp_app_init(RtpSession *session, uint8_t *buf, uint8_t subtype, con
 	rtcp_app_t *app=(rtcp_app_t*)buf;
 	if (size<sizeof(rtcp_app_t)) return 0;
 	rtcp_common_header_init(&app->ch,session,RTCP_APP,subtype,size);
-	app->ssrc=htonl(session->send_ssrc);
+	app->ssrc=htonl(session->snd.ssrc);
 	memset(app->name,0,4);
 	strncpy(app->name,name,4);
 	return sizeof(rtcp_app_t);
@@ -310,7 +318,8 @@ static mblk_t * make_sr(RtpSession *session){
 	cm=allocb(sizeof(rtcp_sr_t),0);
 	cm->b_wptr+=rtcp_sr_init(session,cm->b_wptr,sizeof(rtcp_sr_t));
 	/* make a SDES packet */
-	sdes=rtp_session_create_rtcp_sdes_packet(session);
+	if (session->sd!=NULL)
+		sdes=rtp_session_create_rtcp_sdes_packet(session);
 	/* link them */
 	cm->b_cont=sdes;
 	return cm;
@@ -332,7 +341,7 @@ void rtp_session_rtcp_process_send(RtpSession *session){
 
 void rtp_session_rtcp_process_recv(RtpSession *session){
 	RtpStream *st=&session->rtp;
-	mblk_t *m;
+	mblk_t *m=NULL;
 	if (st->rcv_last_app_ts - st->last_rtcp_report_snt_r > st->rtcp_report_snt_interval 
 		|| st->snd_last_ts - st->last_rtcp_report_snt_s > st->rtcp_report_snt_interval){
 		st->last_rtcp_report_snt_r=st->rcv_last_app_ts;
@@ -341,12 +350,15 @@ void rtp_session_rtcp_process_recv(RtpSession *session){
 		if (session->rtp.last_rtcp_packet_count<session->rtp.stats.packet_sent){
 			m=make_sr(session);
 			session->rtp.last_rtcp_packet_count=session->rtp.stats.packet_sent;
-		}else{
+		}else if (session->rtp.stats.packet_recv>0){
+			/*don't send RR when no packet are received yet*/
 			m=make_rr(session);
 		}
-		/* send the compound packet */
-		rtp_session_rtcp_send(session,m);
-		ortp_debug("Rtcp compound message sent.");
+		if (m!=NULL){
+			/* send the compound packet */
+			rtp_session_rtcp_send(session,m);
+			ortp_debug("Rtcp compound message sent.");
+		}
 	}
 }
 
@@ -360,15 +372,9 @@ void rtp_session_send_rtcp_APP(RtpSession *session, uint8_t subtype, const char
 }
 
 /**
- *rtp_session_bye:
- *@session: #RtpSession to send RTCP BYE packet on.
- *@mode: One of the #RtpSessionMode flags.
- *
- *  Creates a new rtp session.
- *  If the session is able to send data (RTP_SESSION_SENDONLY or RTP_SESSION_SENDRECV), then a
- *  random SSRC number is choosed for the outgoing stream.
- *
- *Returns: the newly created rtp session.
+ * Sends a RTCP bye packet.
+ *@param session RtpSession
+ *@param reason the reason phrase.
 **/
 int
 rtp_session_bye(RtpSession *session, const char *reason)
@@ -379,12 +385,10 @@ rtp_session_bye(RtpSession *session, const char *reason)
     int ret;
 
     /* Make a BYE packet (will be on the end of the compund packet). */
-    bye = rtcp_create_simple_bye_packet(session->send_ssrc, reason);
+    bye = rtcp_create_simple_bye_packet(session->snd.ssrc, reason);
 
-    /* SR or RR should be determined by the fact whether st was sent,
-       not on the mode. But we follow the current ortplib logic. */
-    if (session->mode==RTP_SESSION_SENDONLY
-        || session->mode==RTP_SESSION_SENDRECV)
+    /* SR or RR is determined by the fact whether stream was sent*/
+    if (session->rtp.stats.packet_sent>0)
     {
         cm = allocb(sizeof(rtcp_sr_t), 0);
         cm->b_wptr += rtcp_sr_init(session,cm->b_wptr, sizeof(rtcp_sr_t));
@@ -392,13 +396,13 @@ rtp_session_bye(RtpSession *session, const char *reason)
         sdes = rtp_session_create_rtcp_sdes_packet(session);
         /* link them */
         concatb(concatb(cm, sdes), bye);
-    } else {
+    } else if (session->rtp.stats.packet_recv>0){
         /* make a RR packet */
         cm = allocb(sizeof(rtcp_rr_t), 0);
         cm->b_wptr += rtcp_rr_init(session, cm->b_wptr, sizeof(rtcp_rr_t));
         /* link them */
         cm->b_cont = bye;
-    }
+    }else cm=bye;
 
     /* Send compound packet. */
     ret = rtp_session_rtcp_send(session, cm);
