@@ -23,6 +23,7 @@
 #include "utils.h"
 #include "rtpsession_priv.h"
 
+#define SSRC_CHANGED_THRESHOLD 50
 
 void split_and_queue(queue_t *q, int maxrqsz, mblk_t *mp, rtp_header_t *rtp, int *discarded)
 {
@@ -131,15 +132,33 @@ void rtp_session_rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_t
 
 	for (i=0;i<rtp->cc;i++)
 		rtp->csrc[i]=ntohl(rtp->csrc[i]);
-	if (session->rcv.ssrc!=0)
-	{
+	/*the goal of the following code is to lock on an incoming SSRC to avoid
+	receiving "mixed streams"*/
+	if (session->ssrc_set){
 		/*the ssrc is set, so we must check it */
 		if (session->rcv.ssrc!=rtp->ssrc){
-			/*ortp_debug("rtp_parse: bad ssrc - %i",rtp->ssrc);*/
-			session->rcv.ssrc=rtp->ssrc;
-			rtp_signal_table_emit(&session->on_ssrc_changed);
+			if (session->inc_ssrc_candidate==rtp->ssrc){
+				session->inc_same_ssrc_count++;
+			}else{
+				session->inc_same_ssrc_count=0;
+				session->inc_ssrc_candidate=rtp->ssrc;
+			}
+			if (session->inc_same_ssrc_count>SSRC_CHANGED_THRESHOLD){
+				session->rcv.ssrc=rtp->ssrc;
+				rtp_signal_table_emit(&session->on_ssrc_changed);
+			}else{
+				/*discard the packet*/
+				ortp_debug("Receiving packet with unknown ssrc.");
+				stats->bad++;
+				ortp_global_stats.bad++;
+				freemsg(mp);
+				return;
+			}
 		}
-	}else session->rcv.ssrc=rtp->ssrc;
+	}else{
+		session->ssrc_set=TRUE;
+		session->rcv.ssrc=rtp->ssrc;
+	}
 	
 	/* update some statistics */
 	{
