@@ -970,10 +970,13 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	}
 	/*calculate the stream timestamp from the user timestamp */
 	ts = user_ts + session->rtp.rcv_diff_ts;
-	if (session->permissive || session->rtp.jittctl.enabled==FALSE)
-		mp = rtp_getq_permissive(&session->rtp.rq, ts,&rejected);
-	else
-		mp = rtp_getq(&session->rtp.rq, ts,&rejected);
+	if (session->rtp.jittctl.enabled==TRUE){
+		if (session->permissive)
+			mp = rtp_getq_permissive(&session->rtp.rq, ts,&rejected);
+		else{
+			mp = rtp_getq(&session->rtp.rq, ts,&rejected);
+		}
+	}else mp=getq(&session->rtp.rq);/*no jitter buffer at all*/
 	
 	stream->stats.outoftime+=rejected;
 	ortp_global_stats.outoftime+=rejected;
