@@ -504,9 +504,28 @@ static char * ortp_inet_ntoa(struct sockaddr *addr, int addrlen, char *dest, int
  *
  *	Returns: 0 on success.
 **/
-
 int
 rtp_session_set_remote_addr (RtpSession * session, const char * addr, int port)
+{
+  return rtp_session_set_remote_addr_and_port (session, addr, port, port+1);
+}
+
+/**
+ *rtp_session_set_remote_addr_and_port:
+ *@session:		a rtp session freshly created.
+ *@addr:		a local IP address in the xxx.xxx.xxx.xxx form.
+ *@rtp_port:		a local rtp port.
+ *@rtcp_port:		a local rtcp port.
+ *
+ *	Sets the remote address of the rtp session, ie the destination address where rtp packet
+ *	are sent. If the session is recv-only or duplex, it also sets the origin of incoming RTP 
+ *	packets. Rtp packets that don't come from addr:port are discarded.
+ *
+ *	Returns: 0 on success.
+**/
+
+int
+rtp_session_set_remote_addr_and_port (RtpSession * session, const char * addr, int rtp_port, int rtcp_port)
 {
 	int err;
 #ifdef ORTP_INET6
@@ -515,7 +534,7 @@ rtp_session_set_remote_addr (RtpSession * session, const char * addr, int port)
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_family = PF_UNSPEC;
 	hints.ai_socktype = SOCK_DGRAM;
-	snprintf(num, sizeof(num), "%d", port);
+	snprintf(num, sizeof(num), "%d", rtp_port);
 	err = getaddrinfo(addr, num, &hints, &res0);
 	if (err) {
 		ortp_warning ("Error in socket address: %s", gai_strerror(err));
@@ -549,14 +568,14 @@ rtp_session_set_remote_addr (RtpSession * session, const char * addr, int port)
 	}
 	freeaddrinfo(res0);
 	if (err) {
-		ortp_warning("Could not set destination for RTP socket to %s:%i.",addr,port);
+		ortp_warning("Could not set destination for RTP socket to %s:%i.",addr,rtp_port);
 		return -1;
 	}
 	
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_family = PF_UNSPEC;
 	hints.ai_socktype = SOCK_DGRAM;
-	snprintf(num, sizeof(num), "%d", (port + 1));
+	snprintf(num, sizeof(num), "%d", rtcp_port);
 	err = getaddrinfo(addr, num, &hints, &res0);
 	if (err) {
 		ortp_warning ("Error: %s", gai_strerror(err));
@@ -574,7 +593,7 @@ rtp_session_set_remote_addr (RtpSession * session, const char * addr, int port)
 	}
 	freeaddrinfo(res0);
 	if (err) {
-		ortp_warning("Could not set destination for RCTP socket to %s:%i.",addr,port+1);
+		ortp_warning("Could not set destination for RCTP socket to %s:%i.",addr,rtcp_port);
 		return -1;
 	}
 #else
@@ -587,11 +606,11 @@ rtp_session_set_remote_addr (RtpSession * session, const char * addr, int port)
 		ortp_warning ("Error in socket address:%s.", getSocketError());
 		return err;
 	}
-	session->rtp.rem_addr.sin_port = htons (port);
+	session->rtp.rem_addr.sin_port = htons (rtp_port);
 
 	memcpy (&session->rtcp.rem_addr, &session->rtp.rem_addr,
 		sizeof (struct sockaddr_in));
-	session->rtcp.rem_addr.sin_port = htons (port + 1);
+	session->rtcp.rem_addr.sin_port = htons (rtcp_port);
 	session->rtcp.rem_addrlen=sizeof(session->rtcp.rem_addr);
 #endif
 	if (can_connect(session)){
