@@ -283,9 +283,6 @@ int rtp_session_send_dtmf2(RtpSession *session, char dtmf, uint32_t userts, int
 	/* we need to copymsg() instead of dupmsg() because the buffers are modified when
 	the packet is sended because of the host-to-network conversion of timestamp,ssrc, csrc, and
 	seq number.
-	It could be avoided by making a copy of the buffer when sending physically the packet, but
-	it add one more copy for every buffer.
-	Using iomapped socket, it is possible to avoid the user to kernel copy.
 	*/
 	rtp_session_sendm_with_ts(session,m3,userts);
 	session->rtp.snd_seq--;
@@ -404,7 +401,8 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 				freemsg(session->current_tev);
 				session->current_tev=NULL;
 			}
-			session->current_tev=dupmsg(m0);
+			session->current_tev=copymsg(m0);
+			notify_events_ended(session,events,num);
 		}
 	}
 	else
